@@ -277,6 +277,7 @@ ms_obj_new (MSObjAttrBag *attrs)
 	obj->attrs = (attrs != NULL) ? attrs : ms_obj_attr_bag_new ();
 	obj->ignore_combo_in_filter	= FALSE;
 	obj->is_linked			= FALSE;
+	obj->comment_pos.col = obj->comment_pos.row = -1;
 
 	return obj;
 }
@@ -332,36 +333,26 @@ ms_read_TXO (BiffQuery *q)
 	g_return_val_if_fail (1 <= halign && halign <= 4, NULL);
 	g_return_val_if_fail (1 <= valign && valign <= 4, NULL);
 
-	text = g_new (char, text_len + 1);
-	text [0] = '\0';
-	if (ms_biff_query_peek_next (q, &peek_op) &&
-	    peek_op == BIFF_CONTINUE) {
-		guint8 *data;
-		int i, increment = 1;
-
+	if (ms_biff_query_peek_next (q, &peek_op) && peek_op == BIFF_CONTINUE) {
 		ms_biff_query_next (q);
-		increment = (GSF_LE_GET_GUINT8 (q->data)) ? 2 : 1;
-		data = q->data + 1;
 
-		/*
-		 * FIXME: Use biff_get_text or something ?
-		 */
-		if ((int)q->length < increment * text_len) {
-			g_free (text);
+		if ((int)q->length < text_len) {
+			g_warning ("Broken continue in TXO record");
 			text = g_strdup ("Broken continue");
-		} else {
-			for (i = 0; i < text_len ; ++i)
-				text [i] = data [i * increment];
-			text [text_len] = '\0';
-		}
+		} else
+			text = ms_biff_get_chars (q->data + 1, text_len,
+						  *(q->data) != 0);
 
 		if (ms_biff_query_peek_next (q, &peek_op) &&
 		    peek_op == BIFF_CONTINUE)
 			ms_biff_query_next (q);
 		else
 			g_warning ("Unusual, TXO text with no formatting has 0x%x @ 0x%x", peek_op, q->streamPos);
-	} else if (text_len > 0)
-		g_warning ("TXO len of %d but no continue", text_len);
+	} else {
+		if (text_len > 0)
+			g_warning ("TXO len of %d but no continue", text_len);
+		text = g_strdup ("");
+	}
 
 #ifndef NO_DEBUG_EXCEL
 	if (ms_excel_object_debug > 0) {
@@ -531,9 +522,44 @@ ms_obj_read_pre_biff8_obj (BiffQuery *q, MSContainer *container, MSObj *obj)
 		break;
 	case 0xF  : /* dialog frame */
 		break;
-	case 0x10 : /* spinner */
-		break;
-	case 0x11 : /* scrollbar */
+	case 0x10 : /* spinner & scrollbar (layout is the same) */
+	case 0x11 :
+		ms_obj_attr_bag_insert (obj->attrs,
+			ms_obj_attr_new_uint (MS_OBJ_ATTR_SCROLLBAR_VALUE,
+				GSF_LE_GET_GUINT16 (q->data+48)));
+		ms_obj_attr_bag_insert (obj->attrs,
+			ms_obj_attr_new_uint (MS_OBJ_ATTR_SCROLLBAR_MIN,
+				GSF_LE_GET_GUINT16 (q->data+50)));
+		ms_obj_attr_bag_insert (obj->attrs,
+			ms_obj_attr_new_uint (MS_OBJ_ATTR_SCROLLBAR_MAX,
+				GSF_LE_GET_GUINT16 (q->data+52)));
+		ms_obj_attr_bag_insert (obj->attrs,
+			ms_obj_attr_new_uint (MS_OBJ_ATTR_SCROLLBAR_INC,
+				GSF_LE_GET_GUINT16 (q->data+54)));
+		ms_obj_attr_bag_insert (obj->attrs,
+			ms_obj_attr_new_uint (MS_OBJ_ATTR_SCROLLBAR_PAGE,
+				GSF_LE_GET_GUINT16 (q->data+56)));
+
+		{
+			GnmExpr const *ref;
+			guint16 len;
+			guint8 const *last = q->data + q->length;
+			guint8 const *ptr = q->data + 64;
+
+			ptr += 1 + *ptr;		/* object name */
+			if ((ptr - q->data) & 1) ptr++;	/* align on word */
+			if (ptr >= last) break;
+
+			ptr += 2 + GSF_LE_GET_GUINT16 (ptr); /* the macro */
+			if ((ptr - q->data) & 1) ptr++;	/* align on word */
+			if (ptr >= last) break;
+
+			len = GSF_LE_GET_GUINT16 (ptr+2); /* the assigned macro */
+			ref = ms_container_parse_expr (container, ptr + 8, len);
+			if (ref != NULL)
+				ms_obj_attr_bag_insert (obj->attrs,
+					ms_obj_attr_new_expr (MS_OBJ_ATTR_SCROLLBAR_LINK, ref));
+		}
 		break;
 	case 0x12 : /* list box */
 		break;
@@ -640,7 +666,7 @@ ms_obj_read_biff8_obj (BiffQuery *q, MSContainer *container, MSObj *obj)
 			ms_obj_dump (data, len, data_len_left, "RadioButton");
 			break;
 
-		case GR_SCROLLBAR : {
+		case GR_SCROLLBAR :
 			ms_obj_attr_bag_insert (obj->attrs,
 				ms_obj_attr_new_uint (MS_OBJ_ATTR_SCROLLBAR_VALUE,
 					GSF_LE_GET_GUINT16 (data+8)));
@@ -658,7 +684,6 @@ ms_obj_read_biff8_obj (BiffQuery *q, MSContainer *container, MSObj *obj)
 					GSF_LE_GET_GUINT16 (data+16)));
 			ms_obj_dump (data, len, data_len_left, "ScrollBar");
 			break;
-		}
 
 		case GR_NOTE_STRUCTURE :
 			ms_obj_dump (data, len, data_len_left, "Note");
@@ -892,19 +917,14 @@ ms_read_OBJ (BiffQuery *q, MSContainer *container, MSObjAttrBag *attrs)
 		obj->gnum_obj = (*container->vtbl->create_obj) (container, obj);
 
 	/* Chart, There should be a BOF next */
-	if (obj->excel_type == 0x5) {
-		if (ms_excel_read_chart (q, container, obj->gnum_obj)) {
-			ms_obj_delete (obj);
-			return;
-		}
-	}
-
-	if (obj->gnum_obj == NULL) {
+	if (obj->excel_type == 0x5 &&
+	    ms_excel_read_chart_BOF (q, container, obj->gnum_obj)) {
 		ms_obj_delete (obj);
 		return;
 	}
+
 #if 0
-	printf ("Registered object 0x%p\n", obj);
+	g_warning ("registered obj %d\n", obj->id);
 #endif
 	ms_container_add_obj (container, obj);
 }
@@ -965,3 +985,8 @@ ms_objv8_write_listbox (BiffPut *bp, gboolean filtered)
 		GSF_LE_SET_GUINT16 (buf + 14, 0xa);
 	ms_biff_put_var_write (bp, buf, sizeof data);
 }
+
+void
+ms_objv8_write_chart (BiffPut *bp, SheetObject *sog)
+{
+}
