@@ -31,7 +31,11 @@ typedef enum {
 	MS_OBJ_ATTR_IS_INT_MASK = 0x1000,
 	MS_OBJ_ATTR_BLIP_ID,
 	MS_OBJ_ATTR_FONT_COLOR,
+	MS_OBJ_ATTR_FILL_TYPE,
 	MS_OBJ_ATTR_FILL_COLOR,
+	MS_OBJ_ATTR_FILL_ALPHA,
+	MS_OBJ_ATTR_FILL_BACKGROUND,
+	MS_OBJ_ATTR_FILL_BACKGROUND_ALPHA,
 	MS_OBJ_ATTR_OUTLINE_COLOR,
 	MS_OBJ_ATTR_SCROLLBAR_VALUE,
 	MS_OBJ_ATTR_SCROLLBAR_MIN,
@@ -103,7 +107,7 @@ struct _MSObj {
 	char const	*excel_type_name;
 
 	/* a kludge for now until the indicator and the box have distinct objects */
-	CellPos		 comment_pos;
+	GnmCellPos	 comment_pos;
 	gboolean	 ignore_combo_in_filter;
 	gboolean	 is_linked;
 	GHashTable	*attrs;
