@@ -50,7 +50,7 @@ GNUMERIC_MODULE_PLUGIN_INFO_DECL;
  * Finds the cells from the given column that match the criteria.
  */
 static GSList *
-find_cells_that_match (Sheet *sheet, Value *database,
+find_cells_that_match (Sheet *sheet, GnmValue *database,
 		       int col, GSList *criterias)
 {
 	GSList *ptr, *condition, *cells;
@@ -69,7 +69,7 @@ find_cells_that_match (Sheet *sheet, Value *database,
 		if (cell != NULL)
 			cell_eval (cell);
 
-		if (cell_is_blank (cell))
+		if (cell_is_empty (cell))
 			continue;
 
 		add_flag = TRUE;
@@ -86,7 +86,7 @@ find_cells_that_match (Sheet *sheet, Value *database,
 
 				if (cell != NULL)
 					cell_eval (cell);
-				if (cell_is_blank (tmp) ||
+				if (cell_is_empty (tmp) ||
 				    !cond->fun (tmp->value, cond->x)) {
 					add_flag = FALSE;
 					break;
@@ -104,17 +104,17 @@ find_cells_that_match (Sheet *sheet, Value *database,
 }
 
 static void *
-database_find_values (Sheet *sheet, Value *database,
+database_find_values (Sheet *sheet, GnmValue *database,
 		      int col, GSList *criterias,
 		      CollectFlags flags,
 		      int *pcount,
-		      Value **error,
+		      GnmValue **error,
 		      gboolean floats)
 {
 	GSList *cells, *current;
 	int cellcount, count;
 	gnm_float *res1 = NULL;
-	Value **res2 = NULL;
+	GnmValue **res2 = NULL;
 	void *res;
 
 	/* FIXME: expand and sanitise this call later.  */
@@ -125,10 +125,10 @@ database_find_values (Sheet *sheet, Value *database,
 	if (floats)
 		res = res1 = g_new (gnm_float, cellcount + 1);
 	else
-		res = res2 = g_new (Value *, cellcount + 1);
+		res = res2 = g_new (GnmValue *, cellcount + 1);
 	for (count = 0, current = cells; current; current = current->next) {
 		Cell *cell = current->data;
-		Value *value = cell->value;
+		GnmValue *value = cell->value;
 
 		if ((flags & COLLECT_IGNORE_STRINGS) && value->type == VALUE_STRING)
 			continue;
@@ -147,11 +147,11 @@ database_find_values (Sheet *sheet, Value *database,
 
 /***************************************************************************/
 
-static Value *
+static GnmValue *
 database_float_range_function (FunctionEvalInfo *ei,
-			       Value *database,
-			       Value *field,
-			       Value *criteria,
+			       GnmValue *database,
+			       GnmValue *field,
+			       GnmValue *criteria,
 			       float_range_function_t func,
 			       CollectFlags flags,
 			       GnmStdError zero_count_error,
@@ -164,7 +164,7 @@ database_float_range_function (FunctionEvalInfo *ei,
 	int err;
 	gnm_float *vals = NULL;
 	gnm_float fres;
-	Value *res;
+	GnmValue *res;
 
 	fieldno = find_column_of_field (ei->pos, database, field);
 	if (fieldno < 0)
@@ -204,13 +204,13 @@ database_float_range_function (FunctionEvalInfo *ei,
 
 /***************************************************************************/
 
-typedef int (*value_range_function_t) (Value **, int, Value **);
+typedef int (*value_range_function_t) (GnmValue **, int, GnmValue **);
 
-static Value *
+static GnmValue *
 database_value_range_function (FunctionEvalInfo *ei,
-			       Value *database,
-			       Value *field,
-			       Value *criteria,
+			       GnmValue *database,
+			       GnmValue *field,
+			       GnmValue *criteria,
 			       value_range_function_t func,
 			       CollectFlags flags,
 			       GnmStdError zero_count_error,
@@ -221,8 +221,8 @@ database_value_range_function (FunctionEvalInfo *ei,
 	Sheet *sheet;
 	int count;
 	int err;
-	Value **vals = NULL;
-	Value *res;
+	GnmValue **vals = NULL;
+	GnmValue *res;
 
 	fieldno = find_column_of_field (ei->pos, database, field);
 	if (fieldno < 0)
@@ -273,23 +273,25 @@ static char const *help_daverage = {
 	   "The first row of a database contains labels for each column. " \
 	   "\n\n" \
 	   "@field specifies which column is used in the function.  If " \
-	   "@field is an integer, for example. 2, the second column is used. " \
+	   "@field is an integer, for example 2, the second column is used. " \
 	   "Field can also be the label of a column.  For example, ``Age'' " \
 	   "refers to the column with the label ``Age'' in @database range. " \
 	   "\n\n" \
 	   "@criteria is the range of cells which contains the specified " \
 	   "conditions.  The first row of a @criteria should contain the " \
-	   "labels of the fields for which the criterias are for.  Cells " \
+	   "labels of the fields for which the criteria are for.  Cells " \
 	   "below the labels specify conditions, for example, ``>3'' or " \
-	   "``<9''.  Equality condition can be given simply by specifing a " \
-	   "value, e.g. ``3'' or ``John''.  Each row in @criteria specifies " \
-	   "a separate condition, i.e. if a row in @database matches with " \
-	   "one of the rows in @criteria then that row is counted in " \
-	   "(technically speaking boolean OR between the rows in " \
-	   "@criteria).  If @criteria specifies more than one columns then " \
-	   "each of the conditions in these columns should be true that " \
-	   "the row in @database matches (again technically speaking " \
-	   "boolean AND between the columns in each row in @criteria). " \
+	   "``<9''.  Equality condition can be given simply by specifying a " \
+	   "value, e.g. ``3'' or ``John''. \n"\
+	   "Each row in @criteria specifies a separate condition. "\
+           "If a row in "\
+	   "@database matches a row in @criteria, then that row is counted. "\
+	   "Technically speaking, this a boolean OR operation between the "\
+	   "rows in @criteria.\n"\
+	   "If @criteria specifies more than one column, then each of the "\
+	   "conditions in the specified columns must be true for the row in "\
+	   "@database to match. Technically speaking, this is a boolean AND "\
+	   "operation between the columns in @criteria.\n"
            "\n" \
 	   "@EXAMPLES=\n" \
 	   "Let us assume that the range A1:C7 contain the following " \
@@ -307,7 +309,6 @@ static char const *help_daverage = {
 	   "<30\n" \
 	   ">40     >46000\n"
 	   "\n"
-	   "@EXAMPLES=\n"
            "DAVERAGE(A1:C7, \"Salary\", A9:A11) equals 42296.3333.\n"
 	   "DAVERAGE(A1:C7, \"Age\", A9:A11) equals 39.\n"
            "DAVERAGE(A1:C7, \"Salary\", A9:B11) equals 40782.5.\n"
@@ -316,8 +317,8 @@ static char const *help_daverage = {
            "@SEEALSO=DCOUNT")
 };
 
-static Value *
-gnumeric_daverage (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_daverage (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return database_float_range_function (ei,
 					      argv[0],
@@ -346,23 +347,25 @@ static char const *help_dcount = {
 	   "The first row of a database contains labels for each column. " \
 	   "\n\n" \
 	   "@field specifies which column is used in the function.  If " \
-	   "@field is an integer, for example. 2, the second column is used. " \
+	   "@field is an integer, for example 2, the second column is used. " \
 	   "Field can also be the label of a column.  For example, ``Age'' " \
 	   "refers to the column with the label ``Age'' in @database range. " \
 	   "\n\n" \
 	   "@criteria is the range of cells which contains the specified " \
 	   "conditions.  The first row of a @criteria should contain the " \
-	   "labels of the fields for which the criterias are for.  Cells " \
+	   "labels of the fields for which the criteria are for.  Cells " \
 	   "below the labels specify conditions, for example, ``>3'' or " \
-	   "``<9''.  Equality condition can be given simply by specifing a " \
-	   "value, e.g. ``3'' or ``John''.  Each row in @criteria specifies " \
-	   "a separate condition, i.e. if a row in @database matches with " \
-	   "one of the rows in @criteria then that row is counted in " \
-	   "(technically speaking boolean OR between the rows in " \
-	   "@criteria).  If @criteria specifies more than one columns then " \
-	   "each of the conditions in these columns should be true that " \
-	   "the row in @database matches (again technically speaking " \
-	   "boolean AND between the columns in each row in @criteria). " \
+	   "``<9''.  Equality condition can be given simply by specifying a " \
+	   "value, e.g. ``3'' or ``John''. \n"\
+	   "Each row in @criteria specifies a separate condition. "\
+           "If a row in "\
+	   "@database matches a row in @criteria, then that row is counted. "\
+	   "Technically speaking, this a boolean OR operation between the "\
+	   "rows in @criteria.\n"\
+	   "If @criteria specifies more than one column, then each of the "\
+	   "conditions in the specified columns must be true for the row in "\
+	   "@database to match. Technically speaking, this is a boolean AND "\
+	   "operation between the columns in @criteria.\n"
            "\n" \
 	   "@EXAMPLES=\n" \
 	   "Let us assume that the range A1:C7 contain the following " \
@@ -380,7 +383,6 @@ static char const *help_dcount = {
 	   "<30\n" \
 	   ">40     >46000\n"
 	   "\n"
-	   "@EXAMPLES=\n"
            "DCOUNT(A1:C7, \"Salary\", A9:A11) equals 3.\n"
            "DCOUNT(A1:C7, \"Salary\", A9:B11) equals 2.\n"
            "DCOUNT(A1:C7, \"Name\", A9:B11) equals 0.\n"
@@ -388,8 +390,8 @@ static char const *help_dcount = {
            "@SEEALSO=DAVERAGE")
 };
 
-static Value *
-gnumeric_dcount (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_dcount (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return database_float_range_function (ei,
 					      argv[0],
@@ -418,23 +420,25 @@ static char const *help_dcounta = {
 	   "The first row of a database contains labels for each column. " \
 	   "\n\n" \
 	   "@field specifies which column is used in the function.  If " \
-	   "@field is an integer, for example. 2, the second column is used. " \
+	   "@field is an integer, for example 2, the second column is used. " \
 	   "Field can also be the label of a column.  For example, ``Age'' " \
 	   "refers to the column with the label ``Age'' in @database range. " \
 	   "\n\n" \
 	   "@criteria is the range of cells which contains the specified " \
 	   "conditions.  The first row of a @criteria should contain the " \
-	   "labels of the fields for which the criterias are for.  Cells " \
+	   "labels of the fields for which the criteria are for.  Cells " \
 	   "below the labels specify conditions, for example, ``>3'' or " \
-	   "``<9''.  Equality condition can be given simply by specifing a " \
-	   "value, e.g. ``3'' or ``John''.  Each row in @criteria specifies " \
-	   "a separate condition, i.e. if a row in @database matches with " \
-	   "one of the rows in @criteria then that row is counted in " \
-	   "(technically speaking boolean OR between the rows in " \
-	   "@criteria).  If @criteria specifies more than one columns then " \
-	   "each of the conditions in these columns should be true that " \
-	   "the row in @database matches (again technically speaking " \
-	   "boolean AND between the columns in each row in @criteria). " \
+	   "``<9''.  Equality condition can be given simply by specifying a " \
+	   "value, e.g. ``3'' or ``John''. \n"\
+	   "Each row in @criteria specifies a separate condition. "\
+           "If a row in "\
+	   "@database matches a row in @criteria, then that row is counted. "\
+	   "Technically speaking, this a boolean OR operation between the "\
+	   "rows in @criteria.\n"\
+	   "If @criteria specifies more than one column, then each of the "\
+	   "conditions in the specified columns must be true for the row in "\
+	   "@database to match. Technically speaking, this is a boolean AND "\
+	   "operation between the columns in @criteria.\n"
            "\n" \
 	   "@EXAMPLES=\n" \
 	   "Let us assume that the range A1:C7 contain the following " \
@@ -452,7 +456,6 @@ static char const *help_dcounta = {
 	   "<30\n" \
 	   ">40     >46000\n"
 	   "\n"
-	   "@EXAMPLES=\n"
            "DCOUNTA(A1:C7, \"Salary\", A9:A11) equals 3.\n"
            "DCOUNTA(A1:C7, \"Salary\", A9:B11) equals 2.\n"
            "DCOUNTA(A1:C7, \"Name\", A9:B11) equals 2.\n"
@@ -460,8 +463,8 @@ static char const *help_dcounta = {
            "@SEEALSO=DCOUNT")
 };
 
-static Value *
-gnumeric_dcounta (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_dcounta (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return database_float_range_function (ei,
 					      argv[0],
@@ -488,23 +491,25 @@ static char const *help_dget = {
 	   "The first row of a database contains labels for each column. " \
 	   "\n\n" \
 	   "@field specifies which column is used in the function.  If " \
-	   "@field is an integer, for example. 2, the second column is used. " \
+	   "@field is an integer, for example 2, the second column is used. " \
 	   "Field can also be the label of a column.  For example, ``Age'' " \
 	   "refers to the column with the label ``Age'' in @database range. " \
 	   "\n\n" \
 	   "@criteria is the range of cells which contains the specified " \
 	   "conditions.  The first row of a @criteria should contain the " \
-	   "labels of the fields for which the criterias are for.  Cells " \
+	   "labels of the fields for which the criteria are for.  Cells " \
 	   "below the labels specify conditions, for example, ``>3'' or " \
-	   "``<9''.  Equality condition can be given simply by specifing a " \
-	   "value, e.g. ``3'' or ``John''.  Each row in @criteria specifies " \
-	   "a separate condition, i.e. if a row in @database matches with " \
-	   "one of the rows in @criteria then that row is counted in " \
-	   "(technically speaking boolean OR between the rows in " \
-	   "@criteria).  If @criteria specifies more than one columns then " \
-	   "each of the conditions in these columns should be true that " \
-	   "the row in @database matches (again technically speaking " \
-	   "boolean AND between the columns in each row in @criteria). " \
+	   "``<9''.  Equality condition can be given simply by specifying a " \
+	   "value, e.g. ``3'' or ``John''. \n"\
+	   "Each row in @criteria specifies a separate condition. "\
+           "If a row in "\
+	   "@database matches a row in @criteria, then that row is counted. "\
+	   "Technically speaking, this a boolean OR operation between the "\
+	   "rows in @criteria.\n"\
+	   "If @criteria specifies more than one column, then each of the "\
+	   "conditions in the specified columns must be true for the row in "\
+	   "@database to match. Technically speaking, this is a boolean AND "\
+	   "operation between the columns in @criteria.\n"
            "\n" \
 	   "@EXAMPLES=\n" \
 	   "Let us assume that the range A1:C7 contain the following " \
@@ -527,7 +532,6 @@ static char const *help_dget = {
 	   "* If more than one items match the conditions, DGET returns #NUM! "
 	   "error.\n"
 	   "\n"
-	   "@EXAMPLES=\n"
            "DGET(A1:C7, \"Salary\", A9:A10) equals 34323.\n"
            "DGET(A1:C7, \"Name\", A9:A10) equals \"Clark\".\n"
 	   "\n"
@@ -535,7 +539,7 @@ static char const *help_dget = {
 };
 
 static int
-range_first (Value **xs, int n, Value **res)
+range_first (GnmValue **xs, int n, GnmValue **res)
 {
 	if (n <= 0)
 		return 1;
@@ -544,8 +548,8 @@ range_first (Value **xs, int n, Value **res)
 	return 0;
 }
 
-static Value *
-gnumeric_dget (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_dget (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return database_value_range_function (ei,
 					      argv[0],
@@ -570,23 +574,25 @@ static char const *help_dmax = {
 	   "The first row of a database contains labels for each column. " \
 	   "\n\n" \
 	   "@field specifies which column is used in the function.  If " \
-	   "@field is an integer, for example. 2, the second column is used. " \
+	   "@field is an integer, for example 2, the second column is used. " \
 	   "Field can also be the label of a column.  For example, ``Age'' " \
 	   "refers to the column with the label ``Age'' in @database range. " \
 	   "\n\n" \
 	   "@criteria is the range of cells which contains the specified " \
 	   "conditions.  The first row of a @criteria should contain the " \
-	   "labels of the fields for which the criterias are for.  Cells " \
+	   "labels of the fields for which the criteria are for.  Cells " \
 	   "below the labels specify conditions, for example, ``>3'' or " \
-	   "``<9''.  Equality condition can be given simply by specifing a " \
-	   "value, e.g. ``3'' or ``John''.  Each row in @criteria specifies " \
-	   "a separate condition, i.e. if a row in @database matches with " \
-	   "one of the rows in @criteria then that row is counted in " \
-	   "(technically speaking boolean OR between the rows in " \
-	   "@criteria).  If @criteria specifies more than one columns then " \
-	   "each of the conditions in these columns should be true that " \
-	   "the row in @database matches (again technically speaking " \
-	   "boolean AND between the columns in each row in @criteria). " \
+	   "``<9''.  Equality condition can be given simply by specifying a " \
+	   "value, e.g. ``3'' or ``John''. \n"\
+	   "Each row in @criteria specifies a separate condition. "\
+           "If a row in "\
+	   "@database matches a row in @criteria, then that row is counted. "\
+	   "Technically speaking, this a boolean OR operation between the "\
+	   "rows in @criteria.\n"\
+	   "If @criteria specifies more than one column, then each of the "\
+	   "conditions in the specified columns must be true for the row in "\
+	   "@database to match. Technically speaking, this is a boolean AND "\
+	   "operation between the columns in @criteria.\n"
            "\n" \
 	   "@EXAMPLES=\n" \
 	   "Let us assume that the range A1:C7 contain the following " \
@@ -604,7 +610,6 @@ static char const *help_dmax = {
 	   "<30\n" \
 	   ">40     >46000\n"
 	   "\n"
-	   "@EXAMPLES=\n"
            "DMAX(A1:C7, \"Salary\", A9:A11) equals 47242.\n"
            "DMAX(A1:C7, \"Age\", A9:A11) equals 45.\n"
            "DMAX(A1:C7, \"Age\", A9:B11) equals 43.\n"
@@ -614,8 +619,8 @@ static char const *help_dmax = {
 
 /***************************************************************************/
 
-static Value *
-gnumeric_dmax (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_dmax (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return database_float_range_function (ei,
 					      argv[0],
@@ -644,23 +649,25 @@ static char const *help_dmin = {
 	   "The first row of a database contains labels for each column. " \
 	   "\n\n" \
 	   "@field specifies which column is used in the function.  If " \
-	   "@field is an integer, for example. 2, the second column is used. " \
+	   "@field is an integer, for example 2, the second column is used. " \
 	   "Field can also be the label of a column.  For example, ``Age'' " \
 	   "refers to the column with the label ``Age'' in @database range. " \
 	   "\n\n" \
 	   "@criteria is the range of cells which contains the specified " \
 	   "conditions.  The first row of a @criteria should contain the " \
-	   "labels of the fields for which the criterias are for.  Cells " \
+	   "labels of the fields for which the criteria are for.  Cells " \
 	   "below the labels specify conditions, for example, ``>3'' or " \
-	   "``<9''.  Equality condition can be given simply by specifing a " \
-	   "value, e.g. ``3'' or ``John''.  Each row in @criteria specifies " \
-	   "a separate condition, i.e. if a row in @database matches with " \
-	   "one of the rows in @criteria then that row is counted in " \
-	   "(technically speaking boolean OR between the rows in " \
-	   "@criteria).  If @criteria specifies more than one columns then " \
-	   "each of the conditions in these columns should be true that " \
-	   "the row in @database matches (again technically speaking " \
-	   "boolean AND between the columns in each row in @criteria). " \
+	   "``<9''.  Equality condition can be given simply by specifying a " \
+	   "value, e.g. ``3'' or ``John''. \n"\
+	   "Each row in @criteria specifies a separate condition. "\
+           "If a row in "\
+	   "@database matches a row in @criteria, then that row is counted. "\
+	   "Technically speaking, this a boolean OR operation between the "\
+	   "rows in @criteria.\n"\
+	   "If @criteria specifies more than one column, then each of the "\
+	   "conditions in the specified columns must be true for the row in "\
+	   "@database to match. Technically speaking, this is a boolean AND "\
+	   "operation between the columns in @criteria.\n"
            "\n" \
 	   "@EXAMPLES=\n" \
 	   "Let us assume that the range A1:C7 contain the following " \
@@ -678,15 +685,14 @@ static char const *help_dmin = {
 	   "<30\n" \
 	   ">40     >46000\n"
 	   "\n"
-	   "@EXAMPLES=\n"
            "DMIN(A1:C7, \"Salary\", A9:B11) equals 34323.\n"
            "DMIN(A1:C7, \"Age\", A9:B11) equals 29.\n"
 	   "\n"
            "@SEEALSO=DMAX")
 };
 
-static Value *
-gnumeric_dmin (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_dmin (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return database_float_range_function (ei,
 					      argv[0],
@@ -715,23 +721,25 @@ static char const *help_dproduct = {
 	   "The first row of a database contains labels for each column. " \
 	   "\n\n" \
 	   "@field specifies which column is used in the function.  If " \
-	   "@field is an integer, for example. 2, the second column is used. " \
+	   "@field is an integer, for example 2, the second column is used. " \
 	   "Field can also be the label of a column.  For example, ``Age'' " \
 	   "refers to the column with the label ``Age'' in @database range. " \
 	   "\n\n" \
 	   "@criteria is the range of cells which contains the specified " \
 	   "conditions.  The first row of a @criteria should contain the " \
-	   "labels of the fields for which the criterias are for.  Cells " \
+	   "labels of the fields for which the criteria are for.  Cells " \
 	   "below the labels specify conditions, for example, ``>3'' or " \
-	   "``<9''.  Equality condition can be given simply by specifing a " \
-	   "value, e.g. ``3'' or ``John''.  Each row in @criteria specifies " \
-	   "a separate condition, i.e. if a row in @database matches with " \
-	   "one of the rows in @criteria then that row is counted in " \
-	   "(technically speaking boolean OR between the rows in " \
-	   "@criteria).  If @criteria specifies more than one columns then " \
-	   "each of the conditions in these columns should be true that " \
-	   "the row in @database matches (again technically speaking " \
-	   "boolean AND between the columns in each row in @criteria). " \
+	   "``<9''.  Equality condition can be given simply by specifying a " \
+	   "value, e.g. ``3'' or ``John''. \n"\
+	   "Each row in @criteria specifies a separate condition. "\
+           "If a row in "\
+	   "@database matches a row in @criteria, then that row is counted. "\
+	   "Technically speaking, this a boolean OR operation between the "\
+	   "rows in @criteria.\n"\
+	   "If @criteria specifies more than one column, then each of the "\
+	   "conditions in the specified columns must be true for the row in "\
+	   "@database to match. Technically speaking, this is a boolean AND "\
+	   "operation between the columns in @criteria.\n"
            "\n" \
 	   "@EXAMPLES=\n" \
 	   "Let us assume that the range A1:C7 contain the following " \
@@ -749,14 +757,13 @@ static char const *help_dproduct = {
 	   "<30\n" \
 	   ">40     >46000\n"
 	   "\n"
-	   "@EXAMPLES=\n"
            "DPRODUCT(A1:C7, \"Age\", A9:B11) equals 1247.\n"
 	   "\n"
            "@SEEALSO=DSUM")
 };
 
-static Value *
-gnumeric_dproduct (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_dproduct (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	/* FIXME: check what happens for zero count.  */
 	return database_float_range_function (ei,
@@ -787,23 +794,25 @@ static char const *help_dstdev = {
 	   "The first row of a database contains labels for each column. " \
 	   "\n\n" \
 	   "@field specifies which column is used in the function.  If " \
-	   "@field is an integer, for example. 2, the second column is used. " \
+	   "@field is an integer, for example 2, the second column is used. " \
 	   "Field can also be the label of a column.  For example, ``Age'' " \
 	   "refers to the column with the label ``Age'' in @database range. " \
 	   "\n\n" \
 	   "@criteria is the range of cells which contains the specified " \
 	   "conditions.  The first row of a @criteria should contain the " \
-	   "labels of the fields for which the criterias are for.  Cells " \
+	   "labels of the fields for which the criteria are for.  Cells " \
 	   "below the labels specify conditions, for example, ``>3'' or " \
-	   "``<9''.  Equality condition can be given simply by specifing a " \
-	   "value, e.g. ``3'' or ``John''.  Each row in @criteria specifies " \
-	   "a separate condition, i.e. if a row in @database matches with " \
-	   "one of the rows in @criteria then that row is counted in " \
-	   "(technically speaking boolean OR between the rows in " \
-	   "@criteria).  If @criteria specifies more than one columns then " \
-	   "each of the conditions in these columns should be true that " \
-	   "the row in @database matches (again technically speaking " \
-	   "boolean AND between the columns in each row in @criteria). " \
+	   "``<9''.  Equality condition can be given simply by specifying a " \
+	   "value, e.g. ``3'' or ``John''. \n"\
+	   "Each row in @criteria specifies a separate condition. "\
+           "If a row in "\
+	   "@database matches a row in @criteria, then that row is counted. "\
+	   "Technically speaking, this a boolean OR operation between the "\
+	   "rows in @criteria.\n"\
+	   "If @criteria specifies more than one column, then each of the "\
+	   "conditions in the specified columns must be true for the row in "\
+	   "@database to match. Technically speaking, this is a boolean AND "\
+	   "operation between the columns in @criteria.\n"
            "\n" \
 	   "@EXAMPLES=\n" \
 	   "Let us assume that the range A1:C7 contain the following " \
@@ -821,15 +830,14 @@ static char const *help_dstdev = {
 	   "<30\n" \
 	   ">40     >46000\n"
 	   "\n"
-	   "@EXAMPLES=\n"
            "DSTDEV(A1:C7, \"Age\", A9:B11) equals 9.89949.\n"
            "DSTDEV(A1:C7, \"Salary\", A9:B11) equals 9135.112506.\n"
 	   "\n"
            "@SEEALSO=DSTDEVP")
 };
 
-static Value *
-gnumeric_dstdev (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_dstdev (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return database_float_range_function (ei,
 					      argv[0],
@@ -859,23 +867,25 @@ static char const *help_dstdevp = {
 	   "The first row of a database contains labels for each column. " \
 	   "\n\n" \
 	   "@field specifies which column is used in the function.  If " \
-	   "@field is an integer, for example. 2, the second column is used. " \
+	   "@field is an integer, for example 2, the second column is used. " \
 	   "Field can also be the label of a column.  For example, ``Age'' " \
 	   "refers to the column with the label ``Age'' in @database range. " \
 	   "\n\n" \
 	   "@criteria is the range of cells which contains the specified " \
 	   "conditions.  The first row of a @criteria should contain the " \
-	   "labels of the fields for which the criterias are for.  Cells " \
+	   "labels of the fields for which the criteria are for.  Cells " \
 	   "below the labels specify conditions, for example, ``>3'' or " \
-	   "``<9''.  Equality condition can be given simply by specifing a " \
-	   "value, e.g. ``3'' or ``John''.  Each row in @criteria specifies " \
-	   "a separate condition, i.e. if a row in @database matches with " \
-	   "one of the rows in @criteria then that row is counted in " \
-	   "(technically speaking boolean OR between the rows in " \
-	   "@criteria).  If @criteria specifies more than one columns then " \
-	   "each of the conditions in these columns should be true that " \
-	   "the row in @database matches (again technically speaking " \
-	   "boolean AND between the columns in each row in @criteria). " \
+	   "``<9''.  Equality condition can be given simply by specifying a " \
+	   "value, e.g. ``3'' or ``John''. \n"\
+	   "Each row in @criteria specifies a separate condition. "\
+           "If a row in "\
+	   "@database matches a row in @criteria, then that row is counted. "\
+	   "Technically speaking, this a boolean OR operation between the "\
+	   "rows in @criteria.\n"\
+	   "If @criteria specifies more than one column, then each of the "\
+	   "conditions in the specified columns must be true for the row in "\
+	   "@database to match. Technically speaking, this is a boolean AND "\
+	   "operation between the columns in @criteria.\n"
            "\n" \
 	   "@EXAMPLES=\n" \
 	   "Let us assume that the range A1:C7 contain the following " \
@@ -893,15 +903,14 @@ static char const *help_dstdevp = {
 	   "<30\n" \
 	   ">40     >46000\n"
 	   "\n"
-	   "@EXAMPLES=\n"
            "DSTDEVP(A1:C7, \"Age\", A9:B11) equals 7.\n"
            "DSTDEVP(A1:C7, \"Salary\", A9:B11) equals 6459.5.\n"
 	   "\n"
            "@SEEALSO=DSTDEV")
 };
 
-static Value *
-gnumeric_dstdevp (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_dstdevp (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return database_float_range_function (ei,
 					      argv[0],
@@ -930,23 +939,25 @@ static char const *help_dsum = {
 	   "The first row of a database contains labels for each column. " \
 	   "\n\n" \
 	   "@field specifies which column is used in the function.  If " \
-	   "@field is an integer, for example. 2, the second column is used. " \
+	   "@field is an integer, for example 2, the second column is used. " \
 	   "Field can also be the label of a column.  For example, ``Age'' " \
 	   "refers to the column with the label ``Age'' in @database range. " \
 	   "\n\n" \
 	   "@criteria is the range of cells which contains the specified " \
 	   "conditions.  The first row of a @criteria should contain the " \
-	   "labels of the fields for which the criterias are for.  Cells " \
+	   "labels of the fields for which the criteria are for.  Cells " \
 	   "below the labels specify conditions, for example, ``>3'' or " \
-	   "``<9''.  Equality condition can be given simply by specifing a " \
-	   "value, e.g. ``3'' or ``John''.  Each row in @criteria specifies " \
-	   "a separate condition, i.e. if a row in @database matches with " \
-	   "one of the rows in @criteria then that row is counted in " \
-	   "(technically speaking boolean OR between the rows in " \
-	   "@criteria).  If @criteria specifies more than one columns then " \
-	   "each of the conditions in these columns should be true that " \
-	   "the row in @database matches (again technically speaking " \
-	   "boolean AND between the columns in each row in @criteria). " \
+	   "``<9''.  Equality condition can be given simply by specifying a " \
+	   "value, e.g. ``3'' or ``John''. \n"\
+	   "Each row in @criteria specifies a separate condition. "\
+           "If a row in "\
+	   "@database matches a row in @criteria, then that row is counted. "\
+	   "Technically speaking, this a boolean OR operation between the "\
+	   "rows in @criteria.\n"\
+	   "If @criteria specifies more than one column, then each of the "\
+	   "conditions in the specified columns must be true for the row in "\
+	   "@database to match. Technically speaking, this is a boolean AND "\
+	   "operation between the columns in @criteria.\n"
            "\n" \
 	   "@EXAMPLES=\n" \
 	   "Let us assume that the range A1:C7 contain the following " \
@@ -964,15 +975,14 @@ static char const *help_dsum = {
 	   "<30\n" \
 	   ">40     >46000\n"
 	   "\n"
-	   "@EXAMPLES=\n"
            "DSUM(A1:C7, \"Age\", A9:B11) equals 72.\n"
            "DSUM(A1:C7, \"Salary\", A9:B11) equals 81565.\n"
 	   "\n"
            "@SEEALSO=DPRODUCT")
 };
 
-static Value *
-gnumeric_dsum (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_dsum (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	/* FIXME: check what happens for zero count.  */
 	return database_float_range_function (ei,
@@ -1003,23 +1013,25 @@ static char const *help_dvar = {
 	   "The first row of a database contains labels for each column. " \
 	   "\n\n" \
 	   "@field specifies which column is used in the function.  If " \
-	   "@field is an integer, for example. 2, the second column is used. " \
+	   "@field is an integer, for example 2, the second column is used. " \
 	   "Field can also be the label of a column.  For example, ``Age'' " \
 	   "refers to the column with the label ``Age'' in @database range. " \
 	   "\n\n" \
 	   "@criteria is the range of cells which contains the specified " \
 	   "conditions.  The first row of a @criteria should contain the " \
-	   "labels of the fields for which the criterias are for.  Cells " \
+	   "labels of the fields for which the criteria are for.  Cells " \
 	   "below the labels specify conditions, for example, ``>3'' or " \
-	   "``<9''.  Equality condition can be given simply by specifing a " \
-	   "value, e.g. ``3'' or ``John''.  Each row in @criteria specifies " \
-	   "a separate condition, i.e. if a row in @database matches with " \
-	   "one of the rows in @criteria then that row is counted in " \
-	   "(technically speaking boolean OR between the rows in " \
-	   "@criteria).  If @criteria specifies more than one columns then " \
-	   "each of the conditions in these columns should be true that " \
-	   "the row in @database matches (again technically speaking " \
-	   "boolean AND between the columns in each row in @criteria). " \
+	   "``<9''.  Equality condition can be given simply by specifying a " \
+	   "value, e.g. ``3'' or ``John''. \n"\
+	   "Each row in @criteria specifies a separate condition. "\
+           "If a row in "\
+	   "@database matches a row in @criteria, then that row is counted. "\
+	   "Technically speaking, this a boolean OR operation between the "\
+	   "rows in @criteria.\n"\
+	   "If @criteria specifies more than one column, then each of the "\
+	   "conditions in the specified columns must be true for the row in "\
+	   "@database to match. Technically speaking, this is a boolean AND "\
+	   "operation between the columns in @criteria.\n"
            "\n" \
 	   "@EXAMPLES=\n" \
 	   "Let us assume that the range A1:C7 contain the following " \
@@ -1037,15 +1049,14 @@ static char const *help_dvar = {
 	   "<30\n" \
 	   ">40     >46000\n"
 	   "\n"
-	   "@EXAMPLES=\n"
            "DVAR(A1:C7, \"Age\", A9:B11) equals 98.\n"
            "DVAR(A1:C7, \"Salary\", A9:B11) equals 83450280.5.\n"
 	   "\n"
            "@SEEALSO=DVARP")
 };
 
-static Value *
-gnumeric_dvar (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_dvar (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return database_float_range_function (ei,
 					      argv[0],
@@ -1075,23 +1086,25 @@ static char const *help_dvarp = {
 	   "The first row of a database contains labels for each column. " \
 	   "\n\n" \
 	   "@field specifies which column is used in the function.  If " \
-	   "@field is an integer, for example. 2, the second column is used. " \
+	   "@field is an integer, for example 2, the second column is used. " \
 	   "Field can also be the label of a column.  For example, ``Age'' " \
 	   "refers to the column with the label ``Age'' in @database range. " \
 	   "\n\n" \
 	   "@criteria is the range of cells which contains the specified " \
 	   "conditions.  The first row of a @criteria should contain the " \
-	   "labels of the fields for which the criterias are for.  Cells " \
+	   "labels of the fields for which the criteria are for.  Cells " \
 	   "below the labels specify conditions, for example, ``>3'' or " \
-	   "``<9''.  Equality condition can be given simply by specifing a " \
-	   "value, e.g. ``3'' or ``John''.  Each row in @criteria specifies " \
-	   "a separate condition, i.e. if a row in @database matches with " \
-	   "one of the rows in @criteria then that row is counted in " \
-	   "(technically speaking boolean OR between the rows in " \
-	   "@criteria).  If @criteria specifies more than one columns then " \
-	   "each of the conditions in these columns should be true that " \
-	   "the row in @database matches (again technically speaking " \
-	   "boolean AND between the columns in each row in @criteria). " \
+	   "``<9''.  Equality condition can be given simply by specifying a " \
+	   "value, e.g. ``3'' or ``John''. \n"\
+	   "Each row in @criteria specifies a separate condition. "\
+           "If a row in "\
+	   "@database matches a row in @criteria, then that row is counted. "\
+	   "Technically speaking, this a boolean OR operation between the "\
+	   "rows in @criteria.\n"\
+	   "If @criteria specifies more than one column, then each of the "\
+	   "conditions in the specified columns must be true for the row in "\
+	   "@database to match. Technically speaking, this is a boolean AND "\
+	   "operation between the columns in @criteria.\n"
            "\n" \
 	   "@EXAMPLES=\n" \
 	   "Let us assume that the range A1:C7 contain the following " \
@@ -1109,15 +1122,14 @@ static char const *help_dvarp = {
 	   "<30\n" \
 	   ">40     >46000\n"
 	   "\n"
-	   "@EXAMPLES=\n"
            "DVARP(A1:C7, \"Age\", A9:B11) equals 49.\n"
            "DVARP(A1:C7, \"Salary\", A9:B11) equals 41725140.25.\n"
 	   "\n"
            "@SEEALSO=DVAR")
 };
 
-static Value *
-gnumeric_dvarp (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_dvarp (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return database_float_range_function (ei,
 					      argv[0],
@@ -1151,8 +1163,8 @@ static char const *help_getpivotdata = {
            "@SEEALSO=")
 };
 
-static Value *
-gnumeric_getpivotdata (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_getpivotdata (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	int  col, row;
 	Cell *cell;
@@ -1169,7 +1181,7 @@ gnumeric_getpivotdata (FunctionEvalInfo *ei, Value **argv)
 	if (cell != NULL)
 		cell_eval (cell);
 
-	if (cell_is_blank (cell) ||
+	if (cell_is_empty (cell) ||
 	    !VALUE_IS_NUMBER (cell->value))
 		return value_new_error_REF (ei->pos);
 
