@@ -69,8 +69,8 @@ static char const *help_char = {
 	   "@SEEALSO=CODE")
 };
 
-static Value *
-gnumeric_char (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_char (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	int c = value_get_as_int (argv[0]);
 
@@ -103,17 +103,17 @@ static char const *help_unichar = {
 	   "@SYNTAX=UNICHAR(x)\n"
 
 	   "@DESCRIPTION="
-	   "UNICHAR returns the unicode character represented by the number @x.\n"
+	   "UNICHAR returns the Unicode character represented by the number @x.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "UNICHAR(65) equals A.\n"
-	   "CHAR(8232) equals an carriage return error.\n"
+	   "UNICHAR(960) equals a small greek pi.\n"
 	   "\n"
 	   "@SEEALSO=CHAR,UNICODE,CODE")
 };
 
-static Value *
-gnumeric_unichar (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_unichar (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	int c = value_get_as_int (argv[0]);
 
@@ -144,14 +144,14 @@ static char const *help_code = {
 	   "@SEEALSO=CHAR")
 };
 
-static Value *
-gnumeric_code (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_code (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	char const *s = value_peek_string (argv[0]);
 	const unsigned char *us = (const unsigned char *)s;
 	gsize written, clen;
 	char *str;
-	Value *res;
+	GnmValue *res;
 
 	if (*us == 0)
 		value_new_error_VALUE (ei->pos);
@@ -180,7 +180,7 @@ static char const *help_unicode = {
 	   "@SYNTAX=UNICODE(char)\n"
 
 	   "@DESCRIPTION="
-	   "UNICODE returns the unicode number for the character @char.\n\n"
+	   "UNICODE returns the Unicode number for the character @char.\n\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "UNICODE(\"A\") equals 65.\n"
@@ -188,8 +188,8 @@ static char const *help_unicode = {
 	   "@SEEALSO=UNICHAR,CODE,CHAR")
 };
 
-static Value *
-gnumeric_unicode (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_unicode (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	char const *s = value_peek_string (argv[0]);
 
@@ -217,8 +217,8 @@ static char const *help_exact = {
 	   "@SEEALSO=LEN, SEARCH, DELTA")
 };
 
-static Value *
-gnumeric_exact (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_exact (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return value_new_bool (g_utf8_collate (value_peek_string (argv[0]),
 					       value_peek_string (argv[1])) == 0);
@@ -235,13 +235,13 @@ static char const *help_len = {
            "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
-	   "len(\"Helsinki\") equals 8.\n"
+	   "LEN(\"Helsinki\") equals 8.\n"
 	   "\n"
 	   "@SEEALSO=CHAR, CODE")
 };
 
-static Value *
-gnumeric_len (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_len (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return value_new_int (g_utf8_strlen (value_peek_string (argv[0]), -1));
 }
@@ -263,8 +263,8 @@ static char const *help_left = {
 	   "@SEEALSO=MID, RIGHT")
 };
 
-static Value *
-gnumeric_left (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_left (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	char const *peek;
 	int         count, newlen;
@@ -298,8 +298,8 @@ static char const *help_lower = {
 	   "@SEEALSO=UPPER")
 };
 
-static Value *
-gnumeric_lower (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_lower (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return value_new_string_nocopy (g_utf8_strdown (value_peek_string (argv[0]), -1));
 }
@@ -321,8 +321,8 @@ static char const *help_mid = {
 	   "@SEEALSO=LEFT, RIGHT")
 };
 
-static Value *
-gnumeric_mid (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_mid (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	char       *upos;
 	char const *source;
@@ -367,8 +367,8 @@ static char const *help_right = {
 	   "@SEEALSO=MID, LEFT")
 };
 
-static Value *
-gnumeric_right (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_right (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	int count, slen;
 	char const *os;
@@ -404,13 +404,13 @@ static char const *help_upper = {
            "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
-	   "UPPER(\"canceled\") equals \"CANCELED\".\n"
+	   "UPPER(\"cancelled\") equals \"CANCELLED\".\n"
 	   "\n"
 	   "@SEEALSO=LOWER")
 };
 
-static Value *
-gnumeric_upper (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_upper (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return value_new_string_nocopy (g_utf8_strup (value_peek_string (argv[0]), -1));
 }
@@ -421,7 +421,8 @@ static char const *help_concatenate = {
 	N_("@FUNCTION=CONCATENATE\n"
 	   "@SYNTAX=CONCATENATE(string1[,string2...])\n"
 	   "@DESCRIPTION="
-	   "CONCATENATE returns up appended strings.\n\n"
+	   "CONCATENATE returns the string obtained by concatenation of "
+	   "the given strings.\n\n"
            "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
@@ -430,7 +431,7 @@ static char const *help_concatenate = {
 	   "@SEEALSO=LEFT, MID, RIGHT")
 };
 
-static Value *
+static GnmValue *
 gnumeric_concatenate (FunctionEvalInfo *ei, GnmExprList *nodes)
 {
 	return string_range_function (nodes, ei,
@@ -454,8 +455,8 @@ static char const *help_rept = {
 	   "@SEEALSO=CONCATENATE")
 };
 
-static Value *
-gnumeric_rept (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_rept (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	GString    *res;
 	char const *source;
@@ -500,8 +501,8 @@ static char const *help_clean = {
 	   "@SEEALSO=")
 };
 
-static Value *
-gnumeric_clean (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_clean (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	char const *s = value_peek_string (argv[0]);
 	GString *res = g_string_sized_new (strlen (s));
@@ -535,8 +536,8 @@ static char const *help_find = {
 	   "@SEEALSO=EXACT, LEN, MID, SEARCH")
 };
 
-static Value *
-gnumeric_find (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_find (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	int count, haystacksize;
 	char const *haystack, *needle;
@@ -593,8 +594,8 @@ static char const *help_fixed = {
 	   "@SEEALSO=")
 };
 
-static Value *
-gnumeric_fixed (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_fixed (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	int decimals;
 	gnm_float num;
@@ -662,8 +663,8 @@ static char const *help_proper = {
  * (e.g. "US Of A" -> "US of A", "Cent'S Worth" -> "Cent's Worth")
  * but this is how Excel does it
  */
-static Value *
-gnumeric_proper (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_proper (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	char const *p;
 	GString    *res    = g_string_new (NULL);
@@ -709,8 +710,8 @@ static char const *help_replace = {
 	   "@SEEALSO=MID, SEARCH, SUBSTITUTE, TRIM")
 };
 
-static Value *
-gnumeric_replace (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_replace (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	GString *res;
 	gint start, num, oldlen;
@@ -761,8 +762,8 @@ static char const *help_t_ = {
 
 /* Note: gnumeric_t is a reserved symbol.  */
 
-static Value *
-gnumeric_t_ (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_t_ (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	if (argv[0]->type == VALUE_STRING)
 		return value_duplicate (argv[0]);
@@ -786,19 +787,19 @@ static char const *help_text = {
 	   "@SEEALSO=DOLLAR")
 };
 
-static Value *
-gnumeric_text (FunctionEvalInfo *ei, Value **args)
+static GnmValue *
+gnumeric_text (FunctionEvalInfo *ei, GnmValue **args)
 {
 	StyleFormat *format = style_format_new_XL (value_peek_string (args[1]),
 						   TRUE);
-	Value       *res, *tmp = NULL;
-	Value const *arg  = args[0];
+	GnmValue       *res, *tmp = NULL;
+	GnmValue const *arg  = args[0];
 	gboolean    ok = FALSE;
 	GnmDateConventions const *conv =
 		workbook_date_conv (ei->pos->sheet->workbook);
 
 	if (arg->type == VALUE_STRING) {
-		Value *match = format_match (value_peek_string (arg), NULL, conv);
+		GnmValue *match = format_match (value_peek_string (arg), NULL, conv);
 		ok = (match != NULL);
 		if (ok)
 			tmp = match;
@@ -835,8 +836,8 @@ static char const *help_trim = {
 	   "@SEEALSO=CLEAN, MID, REPLACE, SUBSTITUTE")
 };
 
-static Value *
-gnumeric_trim (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_trim (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	char const *s;
 	GString  *res   = g_string_new (NULL);
@@ -887,8 +888,8 @@ static char const *help_value = {
 	   "@SEEALSO=DOLLAR, FIXED, TEXT")
 };
 
-static Value *
-gnumeric_value (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_value (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	switch (argv[0]->type) {
 	case VALUE_EMPTY:
@@ -898,7 +899,7 @@ gnumeric_value (FunctionEvalInfo *ei, Value **argv)
 		return value_duplicate (argv[0]);
 
 	default: {
-		Value *v;
+		GnmValue *v;
 		char const *p, *arg = value_peek_string (argv[0]);
 
 		/* Skip leading spaces */
@@ -932,8 +933,8 @@ static char const *help_substitute = {
 	   "@SEEALSO=REPLACE, TRIM")
 };
 
-static Value *
-gnumeric_substitute (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_substitute (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	char const *p;
 	int oldlen, newlen, len, inst;
@@ -987,67 +988,44 @@ static char const *help_dollar = {
 	   "@SEEALSO=FIXED, TEXT, VALUE")
 };
 
-static Value *
-gnumeric_dollar (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_dollar (FunctionEvalInfo *ei, GnmValue **argv)
 {
-	gboolean precedes, space_sep;
-	char const *curr = format_get_currency (&precedes, &space_sep);
-	char *format, *s;
+	FormatCharacteristics info;
 	StyleFormat *sf;
-	char const *base_format =
-		"%s#,##0%s%s;(%s#,##0%s)%s;_(%s\"-\"??%s_);_(@_)";
+	gnm_float p10;
+	GnmValue *v;
+	char *s, *end;
         gnm_float number = value_get_as_float (argv[0]);
         int decimals = argv[1] ? value_get_as_int (argv[1]) : 2;
-	gnm_float p10;
-	Value *v;
-	char dotdecimals[1000];
 
-	if (decimals > 0) {
-		/* ".0000" */
-		decimals = MIN (decimals, (int)sizeof (dotdecimals) - 2); /* FIXME? */
-		dotdecimals[0] = '.';
-		memset (&dotdecimals[1], '0', decimals);
-		dotdecimals[decimals + 1] = 0;
-	} else {
-		dotdecimals[0] = 0;
-	}
-
-	if (precedes) {
-		char *pre = g_strconcat ("\"", curr, "\"",
-					 (space_sep ? " " : ""),
-					 NULL);
-
-		format = g_strdup_printf (base_format,
-					  pre, dotdecimals, "",
-					  pre, dotdecimals, "",
-					  pre, "");
-		g_free (pre);
-	} else {
-		char *post = g_strconcat ((space_sep ? " " : ""),
-					  "\"", curr, "\"",
-					  NULL);
-
-		format = g_strdup_printf (base_format,
-					  "", dotdecimals, post,
-					  "", dotdecimals, post,
-					  "", post);
-		g_free (post);
-	}
-	sf = style_format_new_XL (format, FALSE);
-	g_free (format);
-	g_return_val_if_fail (sf != NULL,
-			      value_new_error_NA (ei->pos));
+	/* This is what Excel appears to do.  */
+	if (decimals >= 128)
+		return value_new_error_VALUE (ei->pos);
 
 	/* Since decimals can be negative, round the number.  */
 	p10 = gpow10 (decimals);
-	number = gnumeric_fake_round (number * p10) / p10;
+	if (p10 == 0)
+		number = 0; /* Underflow.  */
+	else
+		number = gnumeric_fake_round (number * p10) / p10;
+
+	info = style_format_default_money ()->family_info;
+	info.num_decimals = MAX (decimals, 0);
+	info.negative_fmt = 2;
+
+	sf = style_format_build (FMT_CURRENCY, &info);
 	v = value_new_float (number);
 	s = format_value (sf, v, NULL, -1,
 		workbook_date_conv (ei->pos->sheet->workbook));
 	value_release (v);
-
 	style_format_unref (sf);
 
+	/* Trim terminal space.  */
+	end = s + strlen (s);
+	if (end != s && end[-1] == ' ')
+		end[-1] = 0;
+
 	return value_new_string_nocopy (s);
 }
 
@@ -1055,24 +1033,24 @@ gnumeric_dollar (FunctionEvalInfo *ei, Value **argv)
 
 static char const *help_search = {
 	N_("@FUNCTION=SEARCH\n"
-	   "@SYNTAX=SEARCH(text,within[,start_num])\n"
+	   "@SYNTAX=SEARCH(search_string,text[,start_num])\n"
 	   "@DESCRIPTION="
-	   "SEARCH returns the location of a character or text string within "
-	   "another string.  @text is the string or character to be searched. "
-	   "@within is the string in which you want to search.  @start_num "
-	   "is the start position of the search in @within.  If @start_num "
+	   "SEARCH returns the location of the @search_ string within "
+	   "@text. The search starts  with the @start_num character of text "
+	   "@text.  If @start_num "
 	   "is omitted, it is assumed to be one.  The search is not case "
 	   "sensitive.\n"
 	   "\n"
-	   "@text can contain wildcard characters (*) and question marks (?) "
-	   "to control the search.  A question mark matches with any "
-	   "character and wildcard matches with any string including empty "
+	   "@search_string can contain wildcard characters (*) and "
+	   "question marks (?). "
+	   "A question mark matches any "
+	   "character and a wildcard matches any string including the empty "
 	   "string.  If you want the actual wildcard or question mark to "
-	   "be searched, use tilde (~) before the character.\n"
+	   "be found, use tilde (~) before the character.\n"
 	   "\n"
-	   "* If @text is not found, SEARCH returns #VALUE! error.\n"
+	   "* If @search_string is not found, SEARCH returns #VALUE! error.\n"
 	   "* If @start_num is less than one or it is greater than the length "
-	   "of @within, SEARCH returns #VALUE! error.\n"
+	   "of @text, SEARCH returns #VALUE! error.\n"
            "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
@@ -1082,8 +1060,8 @@ static char const *help_search = {
 	   "@SEEALSO=FIND")
 };
 
-static Value *
-gnumeric_search (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_search (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	char const *needle = value_peek_string (argv[0]);
 	char const *haystack = value_peek_string (argv[1]);
@@ -1091,7 +1069,7 @@ gnumeric_search (FunctionEvalInfo *ei, Value **argv)
 	char const *hay2;
 	gnumeric_regex_t r;
 	regmatch_t rm;
-	Value *res = NULL;
+	GnmValue *res = NULL;
 	int i;
 
 	start--;
@@ -1179,7 +1157,7 @@ const GnmFuncDescriptor string_functions[] = {
         { "right",      "S|f",   N_("text,num_chars"),          &help_right,
 	  gnumeric_right, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
-        { "search",     "SS|f",  N_("find,within,start_num"),   &help_search,
+        { "search",     "SS|f",  N_("search_string,text,start_num"),   &help_search,
 	  gnumeric_search, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "substitute", "SSS|f", N_("text,old,new,num"),       &help_substitute,
