@@ -52,6 +52,8 @@
 
 #include <gsf/gsf-libxml.h>
 #include <gsf/gsf-input.h>
+#include <gsf/gsf-input-memory.h>
+#include <gsf/gsf-input-gzip.h>
 #include <libxml/tree.h>
 #include <libxml/parser.h>
 #include <libxml/parserInternals.h>
@@ -136,7 +138,7 @@ xml_sax_attr_int (xmlChar const * const *attrs, char const *name, int *res)
 }
 
 static gboolean
-xml_sax_attr_cellpos (xmlChar const * const *attrs, char const *name, CellPos *val)
+xml_sax_attr_cellpos (xmlChar const * const *attrs, char const *name, GnmCellPos *val)
 {
 	g_return_val_if_fail (attrs != NULL, FALSE);
 	g_return_val_if_fail (attrs[0] != NULL, FALSE);
@@ -175,7 +177,7 @@ xml_sax_attr_color (xmlChar const * const *attrs, char const *name, StyleColor *
 }
 
 static gboolean
-xml_sax_attr_range (xmlChar const * const *attrs, Range *res)
+xml_sax_attr_range (xmlChar const * const *attrs, GnmRange *res)
 {
 	int flags = 0;
 	for (; attrs[0] && attrs[1] ; attrs += 2)
@@ -231,10 +233,10 @@ typedef struct {
 	} validation;
 
 	gboolean  style_range_init;
-	Range	  style_range;
+	GnmRange	  style_range;
 	MStyle   *style;
 
-	CellPos cell;
+	GnmCellPos cell;
 	int expr_id, array_rows, array_cols;
 	int value_type;
 	StyleFormat *value_fmt;
@@ -582,7 +584,7 @@ xml_sax_selection_range (GsfXMLIn *gsf_state, xmlChar const **attrs)
 {
 	XMLSaxParseState *state = (XMLSaxParseState *)gsf_state;
 
-	Range r;
+	GnmRange r;
 	if (xml_sax_attr_range (attrs, &r))
 		sv_selection_add_range (
 			sheet_get_view (state->sheet, state->wb_view),
@@ -619,7 +621,7 @@ xml_sax_selection_end (GsfXMLIn *gsf_state, G_GNUC_UNUSED GsfXMLBlob *blob)
 {
 	XMLSaxParseState *state = (XMLSaxParseState *)gsf_state;
 
-	CellPos const pos = state->cell;
+	GnmCellPos const pos = state->cell;
 	state->cell.col = state->cell.row = -1;
 	sv_set_edit_pos (sheet_get_view (state->sheet, state->wb_view), &pos);
 }
@@ -629,7 +631,7 @@ xml_sax_sheet_layout (GsfXMLIn *gsf_state, xmlChar const **attrs)
 {
 	XMLSaxParseState *state = (XMLSaxParseState *)gsf_state;
 
-	CellPos tmp;
+	GnmCellPos tmp;
 
 	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
 		if (xml_sax_attr_cellpos (attrs, "TopLeft", &tmp))
@@ -645,7 +647,7 @@ xml_sax_sheet_freezepanes (GsfXMLIn *gsf_state, xmlChar const **attrs)
 {
 	XMLSaxParseState *state = (XMLSaxParseState *)gsf_state;
 
-	CellPos frozen_tl, unfrozen_tl;
+	GnmCellPos frozen_tl, unfrozen_tl;
 	int flags = 0;
 
 	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
@@ -1193,7 +1195,7 @@ xml_sax_cell_content (GsfXMLIn *gsf_state, G_GNUC_UNUSED GsfXMLBlob *blob)
 		} else if (state->version >= GNUM_XML_V3 ||
 			   xml_not_used_old_array_spec (cell, content)) {
 			if (value_type > 0) {
-				Value *v = value_new_from_string (value_type, content, value_fmt, FALSE);
+				GnmValue *v = value_new_from_string (value_type, content, value_fmt, FALSE);
 				cell_set_value (cell, v);
 			} else
 				cell_set_text (cell, content);
@@ -1237,7 +1239,7 @@ xml_sax_merge (GsfXMLIn *gsf_state, G_GNUC_UNUSED GsfXMLBlob *blob)
 {
 	XMLSaxParseState *state = (XMLSaxParseState *)gsf_state;
 
-	Range r;
+	GnmRange r;
 	g_return_if_fail (state->base.content->len > 0);
 
 	if (parse_range (state->base.content->str, &r))
@@ -1264,7 +1266,7 @@ xml_sax_named_expr_end (GsfXMLIn *gsf_state, G_GNUC_UNUSED GsfXMLBlob *blob)
 
 	parse_pos_init_sheet (&pos, state->sheet);
 	if (state->name.position) {
-		CellRef tmp;
+		GnmCellRef tmp;
 		char const *res = cellref_parse (&tmp, state->name.position, &pos.eval);
 		if (res != NULL && *res == '\0') {
 			pos.eval.col = tmp.col;
@@ -1466,6 +1468,90 @@ GSF_XML_IN_NODE_FULL (START, WB, GNM, "Workbook", FALSE, TRUE, FALSE, &xml_sax_w
 };
 static GsfXMLInDoc *doc;
 
+static GsfInput *
+maybe_gunzip (GsfInput *input)
+{
+	GsfInput *gzip = GSF_INPUT (gsf_input_gzip_new (input, NULL));
+	if (gzip) {
+		g_object_unref (input);
+		return gzip;
+	} else {
+		gsf_input_seek (input, 0, G_SEEK_SET);
+		return input;
+	}
+}
+
+static GsfInput *
+maybe_convert (GsfInput *input, gboolean quiet)
+{
+	static char const *noencheader = "<?xml version=\"1.0\"?>";
+	static char const *encheader = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>";
+	guint8 const *buf;
+	gsf_off_t input_size;
+	GString *buffer;
+	guint ui;
+	GsfInput *old_input = input;
+
+	buf = gsf_input_read (input, strlen (noencheader), NULL);
+	if (!buf || strncmp (noencheader, buf, strlen (noencheader)) != 0)
+		return input;
+
+	input_size = gsf_input_remaining (input);
+	buffer = g_string_sized_new (input_size + strlen (encheader));
+	g_string_append (buffer, encheader);
+	if (!gsf_input_read (input, input_size, buffer->str + strlen (encheader))) {
+		g_string_free (buffer, TRUE);
+		return input;
+	}
+	buffer->len = input_size + strlen (encheader);
+	buffer->str[buffer->len] = 0;
+
+	for (ui = 0; ui < buffer->len; ui++) {
+		if (buffer->str[ui] == '&' &&
+		    buffer->str[ui + 1] == '#' &&
+		    g_ascii_isdigit (buffer->str[ui + 2])) {
+			guint start = ui;
+			guint c = 0;
+			ui += 2;
+			while (g_ascii_isdigit (buffer->str[ui])) {
+				c = c * 10 + (buffer->str[ui] - '0');
+				ui++;
+			}
+			if (buffer->str[ui] == ';' && c >= 128 && c <= 255) {
+				buffer->str[start] = c;
+				g_string_erase (buffer, start + 1, ui - start);
+				ui = start;
+			}
+		}
+	}
+
+	if (g_get_charset (NULL)) {
+		input = GSF_INPUT (gsf_input_memory_new (buffer->str, buffer->len, TRUE));
+		g_string_free (buffer, FALSE);
+		if (!quiet)
+			g_warning ("Converted xml document with no encoding from pseudo-UTF-8 to UTF-8.");
+	} else {
+		gsize bytes_written;
+		char *converted =
+			g_locale_to_utf8 (buffer->str, buffer->len,
+					  NULL, &bytes_written, NULL);
+		g_string_free (buffer, TRUE);
+		if (!converted) {
+			gsf_input_seek (input, 0, G_SEEK_SET);
+			if (!quiet)
+				g_warning ("Failed to convert xml document with no encoding from locale to UTF-8.");
+			return input;
+		}
+
+		input = GSF_INPUT (gsf_input_memory_new (converted, bytes_written, TRUE));
+		if (!quiet)
+			g_warning ("Converted xml document with no encoding from locale to UTF-8.");
+	}
+
+	g_object_unref (old_input);
+	return input;
+}
+
 void
 xml_sax_file_open (GnmFileOpener const *fo, IOContext *io_context,
 		   WorkbookView *wb_view, GsfInput *input)
@@ -1497,11 +1583,18 @@ xml_sax_file_open (GnmFileOpener const *fo, IOContext *io_context,
 	state.expr_map = g_hash_table_new (g_direct_hash, g_direct_equal);
 	state.delayed_names = NULL;
 
+	g_object_ref (input);
+	input = maybe_gunzip (input);
+	input = maybe_convert (input, FALSE);
+	gsf_input_seek (input, 0, G_SEEK_SET);
+
 	if (!gsf_xml_in_parse (&state.base, input))
 		gnumeric_io_error_string (io_context, _("XML document not well formed!"));
 	else
 		workbook_queue_all_recalc (state.wb);
 
+	g_object_unref (input);
+
 	/* cleanup */
 	g_hash_table_destroy (state.expr_map);
 }
