@@ -25,7 +25,9 @@
 
 #include <gnumeric-gconf.h>
 #include <gsf/gsf-impl-utils.h>
-#include <gtk/gtk.h>
+#include <gtk/gtkmain.h>
+#include <gtk/gtkiconfactory.h>
+#include <gtk/gtkselection.h>
 
 enum {
 	APPLICATION_PROP_0,
@@ -47,7 +49,7 @@ struct _GnumericApplication {
 	/* Clipboard */
 	SheetView	*clipboard_sheet_view;
 	CellRegion	*clipboard_copied_contents;
-	Range		 clipboard_cut_range;
+	GnmRange	 clipboard_cut_range;
 
 	/* History for file menu */
 	GSList           *history_list;
@@ -207,7 +209,7 @@ application_clipboard_unant (void)
  */
 void
 application_clipboard_cut_copy (WorkbookControl *wbc, gboolean is_cut,
-				SheetView *sv, Range const *area,
+				SheetView *sv, GnmRange const *area,
 				gboolean animate_cursor)
 {
 	g_return_if_fail (IS_SHEET_VIEW (sv));
@@ -270,7 +272,7 @@ application_clipboard_contents_get (void)
 	return app->clipboard_copied_contents;
 }
 
-Range const *
+GnmRange const *
 application_clipboard_area_get (void)
 {
 	/*
@@ -453,7 +455,10 @@ gboolean application_use_auto_complete	  (void) { return gnm_app_prefs->auto_com
 gboolean application_live_scrolling	  (void) { return gnm_app_prefs->live_scrolling; }
 int	 application_auto_expr_recalc_lag (void) { return gnm_app_prefs->recalc_lag; }
 gboolean application_use_transition_keys  (void) { return gnm_app_prefs->transition_keys; }
-void     application_set_transition_keys  (gboolean state) { gnm_app_prefs->transition_keys = state; }
+void     application_set_transition_keys  (gboolean state)
+{
+	((GnmAppPrefs *)gnm_app_prefs)->transition_keys = state;
+}
 
 GConfClient *
 application_get_gconf_client (void)
