@@ -19,16 +19,15 @@ struct _ColRowInfo {
 	unsigned  is_collapsed  : 1;	/* Does this terminate an outline ? */
 	unsigned  hard_size     : 1;	/* are dimensions explicitly set ? */
 	unsigned  visible       : 1;	/* visible */
-	unsigned  filtered      : 1;	/* hidden as a result of a filter (requires !visible) */
-	unsigned  in_filter     : 1;	/* filtered */
+	unsigned  in_filter     : 1;	/* in a filter */
+	unsigned  needs_respan  : 1;	/* mark a row as needing span generation */
 
 	/* TODO : Add per row/col min/max */
 
 	void *spans;	/* Only used for rows */
 };
 
-struct _ColRowCollection
-{
+struct _ColRowCollection {
 	int         max_used;
 	ColRowInfo  default_style;
 	GPtrArray * info;
@@ -47,8 +46,7 @@ struct _ColRowCollection
 #define COLROW_GET_SEGMENT(seg_array, i) \
 	(g_ptr_array_index ((seg_array)->info, COLROW_SEGMENT_INDEX(i)))
 
-struct _ColRowSegment
-{
+struct _ColRowSegment {
 	ColRowInfo *info [COLROW_SEGMENT_SIZE];
 	float	size_pts;
 	int	size_pixels;
@@ -95,8 +93,6 @@ void		   colrow_restore_state_group	(Sheet *sheet, gboolean is_cols,
 /* Support for Col/Row visibility */
 void             colrow_set_outline             (ColRowInfo *cri, int outline_level,
 						 gboolean is_collapsed);
-void		 colrow_adjust_outline_dir	(ColRowCollection *colrows,
-						 gboolean pre_or_post);
 int		 colrow_find_outline_bound	(Sheet const *sheet, gboolean is_cols,
 						 int index, int depth, gboolean inc);
 ColRowVisList	*colrow_get_outline_toggle	(Sheet const *sheet, gboolean is_cols,
@@ -105,7 +101,8 @@ ColRowVisList	*colrow_get_visiblity_toggle	(SheetView *sv, gboolean is_cols,
 						 gboolean visible);
 void		 colrow_set_visibility		(Sheet *sheet, gboolean is_cols,
 						 gboolean visible, int first, int last);
-
+void		 colrow_get_global_outline	(Sheet const *sheet, gboolean is_cols, int depth,
+						 ColRowVisList	**show, ColRowVisList	**hide);
 ColRowVisList	*colrow_vis_list_destroy	(ColRowVisList *list);
 void		 colrow_set_visibility_list	(Sheet *sheet, gboolean is_col,
 						 gboolean visible,
@@ -116,7 +113,6 @@ void		 colrow_set_visibility_list	(Sheet *sheet, gboolean is_col,
 int              colrow_find_adjacent_visible   (Sheet *sheet, gboolean is_col,
 						 int index, gboolean forward);
 
-void             rows_height_update		(Sheet *sheet, Range const *range,
+void             rows_height_update		(Sheet *sheet, GnmRange const *range,
 						 gboolean shrink);
-
 #endif /* GNUMERIC_COLROW_H */
