@@ -212,6 +212,7 @@ gog_object_dup (GogObject const *src, GogObject *new_parent)
 			g_object_set_property (G_OBJECT (dst), props[n]->name, &val);
 			g_value_unset (&val);
 		}
+	g_free (props);
 
 	if (IS_GOG_DATASET (src)) {	/* convenience to save data */
 		GogDataset const *src_set = GOG_DATASET (src);
@@ -636,6 +637,16 @@ gog_object_add_by_role (GogObject *parent, GogObjectRole const *role, GogObject
 	return NULL;
 }
 
+/**
+ * gog_object_add_by_name :
+ * @parent : #GogObject
+ * @role :
+ * @child : optionally null #GogObject
+ *
+ * Returns a newly created child of @parent in @role.  If @child is provided,
+ * it is assumed to be an unaffiliated object that will be assigned in @role.
+ * On failure return NULL.
+ **/
 GogObject *
 gog_object_add_by_name (GogObject *parent,
 			char const *role, GogObject *child)
@@ -644,6 +655,38 @@ gog_object_add_by_name (GogObject *parent,
 		gog_object_find_role_by_name (parent, role), child);
 }
 
+GogObjectPosition
+gog_object_get_pos (GogObject const *obj)
+{
+	g_return_val_if_fail (GOG_OBJECT (obj) != NULL, GOG_POSITION_SPECIAL);
+	return obj->position;
+}
+
+/**
+ * gog_object_set_pos :
+ * @obj : #GogObject
+ * @pos : #GogObjectPosition
+ *
+ * Attempts to set the position of @obj to @pos.
+ * Returns TRUE the new position is permitted.
+ **/
+gboolean
+gog_object_set_pos (GogObject *obj, GogObjectPosition pos)
+{
+	g_return_val_if_fail (GOG_OBJECT (obj) != NULL, FALSE);
+	g_return_val_if_fail (obj->role != NULL, FALSE);
+
+	if (obj->position == pos)
+		return TRUE;
+
+	if ((obj->role->allowable_positions & pos) !=
+	    (pos & (GOG_POSITION_COMPASS|GOG_POSITION_ANY_MANUAL)))
+		return FALSE;
+	obj->position = pos;
+	gog_object_emit_changed (obj, TRUE);
+	return TRUE;
+}
+
 GogObjectRole const *
 gog_object_find_role_by_name (GogObject const *obj, char const *role)
 {
