@@ -29,6 +29,11 @@
 #include <src/gui-util.h>
 #include <glade/glade-xml.h>
 #include <gtk/gtkspinbutton.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkimage.h>
+#include <gtk/gtkrange.h>
+#include <gtk/gtkoptionmenu.h>
+#include <gtk/gtknotebook.h>
 #include <widgets/widget-color-combo.h>
 #include <widgets/color-palette.h>
 #include <widgets/widget-pixmap-combo.h>
@@ -109,7 +114,7 @@ create_color_combo (StylePrefState *state, GOColor initial_val,
 	GtkWidget *w = color_combo_new (NULL, _("Automatic"),
 		NULL, color_group_fetch (group, NULL));
 	color_combo_set_instant_apply (COLOR_COMBO (w), FALSE);
-	gtk_combo_box_set_tearable (GTK_COMBO_BOX (w), FALSE);
+	gnm_combo_box_set_tearable (GNM_COMBO_BOX (w), FALSE);
 	gnome_color_picker_set_use_alpha (COLOR_COMBO (w)->palette->picker, TRUE);
 	gtk_label_set_mnemonic_widget (
 		GTK_LABEL (glade_xml_get_widget (state->gui, label_name)), w);
@@ -850,10 +855,10 @@ font_init (StylePrefState *state, GogStyle const *style, guint32 enable, GtkWidg
 	g_return_if_fail (GTK_NOTEBOOK (optional_notebook) != NULL);
 
 	w = font_selector_new ();
+	font_selector_set_from_pango  (FONT_SELECTOR (w), style->font.font->desc);
 	g_signal_connect (G_OBJECT (w),
 		"font_changed",
 		G_CALLBACK (cb_font_changed), state);
-	font_selector_set_from_pango  (FONT_SELECTOR (w), style->font.font->desc);
 	gtk_notebook_prepend_page (GTK_NOTEBOOK (optional_notebook), w,
 		gtk_label_new (_("Font")));
 	gtk_widget_show (w);
@@ -972,6 +977,8 @@ gog_style_assign (GogStyle *dst, GogStyle const *src)
 
 	if (GOG_FILL_STYLE_IMAGE == dst->fill.type)
 		dst->fill.u.image.filename = g_strdup (dst->fill.u.image.filename);
+
+	dst->interesting_fields = src->interesting_fields;
 }
 
 /**
@@ -1474,11 +1481,14 @@ gog_style_is_different_size (GogStyle const *a, GogStyle const *b)
 	return a->outline.width != b->outline.width ||
 		!go_font_eq (a->font.font, b->font.font);
 }
+
 gboolean
 gog_style_is_marker_visible (GogStyle const *style)
 {
 #warning TODO : make this smarter
-	return style->marker != NULL;
+	return (style->interesting_fields & GOG_STYLE_MARKER) &&
+		style->marker != NULL &&
+		go_marker_get_shape (style->marker) != GO_MARKER_NONE;
 }
 
 gboolean
