@@ -62,6 +62,19 @@
 #include <libart_lgpl/art_pixbuf.h>
 #include <libart_lgpl/art_rgb_pixbuf_affine.h>
 #include <glade/glade.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtknotebook.h>
+#include <gtk/gtkcheckbutton.h>
+#include <gtk/gtkspinbutton.h>
+#include <gtk/gtktogglebutton.h>
+#include <gtk/gtkframe.h>
+#include <gtk/gtkimage.h>
+#include <gtk/gtkoptionmenu.h>
+#include <gtk/gtktextview.h>
+#include <gtk/gtkstock.h>
+#include <libgnomecanvas/gnome-canvas-util.h>
+#include <libgnomecanvas/gnome-canvas-rect-ellipse.h>
+#include <libgnomecanvas/gnome-canvas-pixbuf.h>
 #include <pango/pangoft2.h>
 #include <widgets/widget-color-combo.h>
 
@@ -131,7 +144,7 @@ typedef struct _FormatState
 
 	Sheet		*sheet;
 	SheetView	*sv;
-	Value		*value;
+	GnmValue	*value;
 	MStyle		*style, *result;
 	StyleBorder *borders[STYLE_BORDER_EDGE_MAX];
 
@@ -375,9 +388,9 @@ setup_color_pickers (ColorPicker *picker,
 		"color_changed",
 		G_CALLBACK (preview_update), state);
 	color_combo_set_instant_apply (COLOR_COMBO (combo), FALSE);
-	gtk_combo_box_set_tearable (GTK_COMBO_BOX (combo), FALSE);
+	gnm_combo_box_set_tearable (GNM_COMBO_BOX (combo), FALSE);
 	/* FIXME: Should we disable the focus? Line 793 workbook-format-toolbar.c */
-	gtk_combo_box_set_title (GTK_COMBO_BOX (combo), caption);
+	gnm_combo_box_set_title (GNM_COMBO_BOX (combo), caption);
 
 	/* Connect to the sample canvas and redraw it */
 
@@ -1868,7 +1881,7 @@ cb_validation_rebuild (G_GNUC_UNUSED void *ignored,
 static void
 fmt_dialog_init_validation_page (FormatState *state)
 {
-	Validation const *v = NULL;
+	GnmValidation const *v = NULL;
 	g_return_if_fail (state != NULL);
 
 	/* Setup widgets */
@@ -1922,7 +1935,7 @@ fmt_dialog_init_validation_page (FormatState *state)
 	if (!mstyle_is_element_conflict (state->style, MSTYLE_VALIDATION))
 		v = mstyle_get_validation (state->style);
 	if (v != NULL) {
-		Validation const *v = mstyle_get_validation (state->style);
+		GnmValidation const *v = mstyle_get_validation (state->style);
 		ParsePos pp;
 
 		gtk_option_menu_set_history (state->validation.error.action, v->style);
@@ -2388,7 +2401,7 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno)
 
 static gboolean
 fmt_dialog_selection_type (SheetView *sv,
-			   Range const *range,
+			   GnmRange const *range,
 			   gpointer user_data)
 {
 	FormatState *state = user_data;
@@ -2396,7 +2409,7 @@ fmt_dialog_selection_type (SheetView *sv,
 	gboolean allow_multi =
 		merged == NULL ||
 		merged->next != NULL ||
-		!range_equal ((Range *)merged->data, range);
+		!range_equal ((GnmRange *)merged->data, range);
 	g_slist_free (merged);
 
 	if (allow_multi) {
