@@ -37,6 +37,7 @@
 #include <command-context.h>
 
 #include <glade/glade.h>
+#include <gtk/gtkradiobutton.h>
 
 #define DELETE_CELL_DIALOG_KEY "delete-cells-dialog"
 
@@ -45,7 +46,7 @@ typedef struct {
 	GtkWidget          *dialog;
 	GtkWidget          *ok_button;
 	GtkWidget          *cancel_button;
-	Range const        *sel;
+	GnmRange const        *sel;
 	Sheet              *sheet;
 	GladeXML           *gui;
 } DeleteCellState;
@@ -126,7 +127,7 @@ dialog_delete_cells (WorkbookControlGUI *wbcg)
 	DeleteCellState *state;
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
 	SheetView	*sv  = wb_control_cur_sheet_view (wbc);
-	Range const *sel;
+	GnmRange const *sel;
 	GladeXML    *gui;
 	int  cols, rows;
 
