@@ -45,6 +45,10 @@
 #include <widgets/gnumeric-cell-renderer-expr-entry.h>
 
 #include <gdk/gdkkeysyms.h>
+#include <gtk/gtktreestore.h>
+#include <gtk/gtktreeview.h>
+#include <gtk/gtktreeselection.h>
+#include <gtk/gtktogglebutton.h>
 #include <locale.h>
 #include <string.h>
 
