@@ -32,6 +32,7 @@
 
 #include "mstyle.h"
 #include "value.h"
+#include "format.h"
 #include "workbook.h"
 #include "number-match.h"
 #include "widgets/widget-font-selector.h"
@@ -42,7 +43,19 @@
 
 #include <gui-util.h>
 #include <glade/glade.h>
-#include <gtk/gtk.h>
+#include <gtk/gtktreeview.h>
+#include <gtk/gtktreestore.h>
+#include <gtk/gtktreeselection.h>
+#include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtkcellrendererpixbuf.h>
+#include <gtk/gtknotebook.h>
+#include <gtk/gtkimage.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtktable.h>
+#include <gtk/gtkstock.h>
+#include <gtk/gtkcheckbutton.h>
+#include <gtk/gtkspinbutton.h>
+#include <gtk/gtktogglebutton.h>
 #include <string.h>
 
 enum {
@@ -406,11 +419,11 @@ pref_tree_set_model (GConfClient *gconf, GtkTreeModel *model, GtkTreeIter *iter)
 		value_string = g_strdup_printf ("%f", gconf_client_get_float (gconf, key,
 									    NULL));
 		break;
-	case GCONF_VALUE_BOOL:
-		value_string = gconf_client_get_bool (gconf, key, NULL) ?
-			g_strdup (_("TRUE")) :
-			g_strdup (_("FALSE"));
+	case GCONF_VALUE_BOOL: {
+		gboolean b = gconf_client_get_bool (gconf, key, NULL);
+		value_string = g_strdup (format_boolean (b));
 		break;
+	}
 	default:
 		value_string = g_strdup ("ERROR FIXME");
 	}
@@ -455,7 +468,7 @@ cb_value_edited (GtkCellRendererText *cell,
 	gint        the_int;
 	gnm_float  the_float;
 	gboolean    the_bool;
-	Value       *value;
+	GnmValue       *value;
 	GConfClient *client = application_get_gconf_client ();
 	GConfSchema *the_schema;
 	gboolean     err;
