@@ -33,6 +33,9 @@
 
 #include <libgnomeui/gnome-entry.h>
 #include <glade/glade.h>
+#include <gtk/gtktogglebutton.h>
+#include <gtk/gtktable.h>
+#include <gtk/gtkstock.h>
 #include <string.h>
 
 #define SEARCH_REPLACE_KEY "search-replace-dialog"
@@ -96,7 +99,7 @@ ok_clicked (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
 	GtkDialog *dialog = dd->dialog;
 	WorkbookControlGUI *wbcg = dd->wbcg;
 	SearchDialogCallback cb = dd->cb;
-	SearchReplace *sr;
+	GnmSearchReplace *sr;
 	char *err;
 	int i;
 
@@ -291,7 +294,7 @@ dialog_search_replace (WorkbookControlGUI *wbcg,
 
 int
 dialog_search_replace_query (WorkbookControlGUI *wbcg,
-			     SearchReplace *sr,
+			     GnmSearchReplace *sr,
 			     const char *location,
 			     const char *old_text,
 			     const char *new_text)
