@@ -43,6 +43,12 @@
 #include <widgets/gnumeric-lazy-list.h>
 #include <libgnomeui/gnome-entry.h>
 #include <glade/glade.h>
+#include <gtk/gtknotebook.h>
+#include <gtk/gtktreeview.h>
+#include <gtk/gtktogglebutton.h>
+#include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtkcellrenderertext.h>
+#include <gtk/gtktable.h>
 #include <string.h>
 
 #define SEARCH_KEY "search-dialog"
@@ -125,8 +131,8 @@ search_get_value (gint row, gint column, gpointer _dd, GValue *value)
 			g_value_set_static_string (value, _("Result"));
 			return;
 		case SRL_contents: {
-			Value *v = cell->value;
-			const char *type;
+			GnmValue *v = cell->value;
+			char const *type;
 
 			gboolean is_expr = cell_has_expr (cell);
 			gboolean is_value = !is_expr && !cell_is_empty (cell) && v;
@@ -158,12 +164,12 @@ search_get_value (gint row, gint column, gpointer _dd, GValue *value)
 			g_value_set_string (value, cell_comment_text_get (item->comment));
 			return;
 		case SRL_value:
-			g_value_set_string_take_ownership
-				(value, value_get_as_string (cell->value));
+			g_value_set_string_take_ownership (value,
+				value_get_as_string (cell->value));
 			return;
 		case SRL_contents:
-			g_value_set_string_take_ownership
-				(value, cell_get_entered_text (cell));
+			g_value_set_string_take_ownership (value,
+				cell_get_entered_text (cell));
 			return;
 #ifndef DEBUG_SWITCH_ENUM
 	default:
@@ -265,7 +271,7 @@ search_clicked (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
 	GladeXML *gui = dd->gui;
 	WorkbookControlGUI *wbcg = dd->wbcg;
 	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
-	SearchReplace *sr;
+	GnmSearchReplace *sr;
 	char *err;
 	int i;
 
