@@ -44,6 +44,10 @@
 
 #include <glade/glade.h>
 #include <widgets/widget-color-combo.h>
+#include <gtk/gtktreeview.h>
+#include <gtk/gtktreeselection.h>
+#include <gtk/gtkstock.h>
+#include <gtk/gtkliststore.h>
 #include <string.h>
 #include <stdio.h>
 
@@ -106,6 +110,7 @@ cb_name_edited (G_GNUC_UNUSED GtkCellRendererText *cell,
 static gint
 location_of_iter (GtkTreeIter  *iter, GtkListStore *model)
 {
+	gint loc;
 	/* Note: in gtk 2.2 we could just do: */
 /* 	gchar* path = gtk_tree_model_get_string_from_iter */
 /* 		(GTK_TREE_MODEL (model), iter); */
@@ -117,8 +122,8 @@ location_of_iter (GtkTreeIter  *iter, GtkListStore *model)
 	gtk_tree_path_free (treepath);
 	/* end of gtk 2.0 code */
 
-	gint loc = atoi(path);
-	
+	loc = atoi(path);
+
 	g_free (path);
 
 	return loc;
@@ -952,12 +957,12 @@ dialog_sheet_order (WorkbookControlGUI *wbcg)
 		_("Default"), NULL, cg);
 	gtk_box_pack_start (vbox, state->ccombo_back, 0, 0, 0);
 	gtk_widget_set_sensitive (state->ccombo_back, FALSE);
-	gtk_combo_box_set_arrow_relief (GTK_COMBO_BOX (state->ccombo_back), GTK_RELIEF_NORMAL);
+	gnm_combo_box_set_arrow_relief (GNM_COMBO_BOX (state->ccombo_back), GTK_RELIEF_NORMAL);
 	color_combo_box_set_preview_relief (COLOR_COMBO (state->ccombo_back), GTK_RELIEF_NORMAL);
 	color_combo_set_instant_apply 
 		(COLOR_COMBO (state->ccombo_back), FALSE);
-	gtk_combo_box_set_tearable 
-		(GTK_COMBO_BOX (state->ccombo_back), FALSE);
+	gnm_combo_box_set_tearable 
+		(GNM_COMBO_BOX (state->ccombo_back), FALSE);
 
 	cg = color_group_fetch ("fore_color_group", wb_control_view (WORKBOOK_CONTROL (wbcg)));
 	state->ccombo_fore = color_combo_new (
@@ -965,12 +970,12 @@ dialog_sheet_order (WorkbookControlGUI *wbcg)
 		_("Default"), NULL, cg);
 	gtk_box_pack_start (vbox, state->ccombo_fore, 1, 1, 0);
 	gtk_widget_set_sensitive (state->ccombo_fore, FALSE);
-	gtk_combo_box_set_arrow_relief (GTK_COMBO_BOX (state->ccombo_fore), GTK_RELIEF_NORMAL);
+	gnm_combo_box_set_arrow_relief (GNM_COMBO_BOX (state->ccombo_fore), GTK_RELIEF_NORMAL);
 	color_combo_box_set_preview_relief (COLOR_COMBO (state->ccombo_fore), GTK_RELIEF_NORMAL);
 	color_combo_set_instant_apply 
 		(COLOR_COMBO (state->ccombo_fore), FALSE);
-	gtk_combo_box_set_tearable 
-		(GTK_COMBO_BOX (state->ccombo_back), FALSE);
+	gnm_combo_box_set_tearable 
+		(GNM_COMBO_BOX (state->ccombo_back), FALSE);
 
 	populate_sheet_list (state);
 
