@@ -23,6 +23,7 @@
 #include <gnumeric-i18n.h>
 #include <gnumeric.h>
 #include "dialogs.h"
+#include "help.h"
 
 #include <gui-util.h>
 #include <workbook-priv.h> /* for Workbook::summary_info */
@@ -133,8 +134,11 @@ dialog_summary_put (SummaryState *state)
 		g_free (txt);
 	}
 	w = glade_xml_get_widget (state->gui, "doc_name");
-	if (w)
-		gtk_entry_set_text (GTK_ENTRY (w), workbook_get_filename (wb));
+	if (w) {
+		char *filename_utf8 = workbook_get_filename_utf8 (wb, FALSE);
+		gtk_entry_set_text (GTK_ENTRY (w), filename_utf8);
+		g_free (filename_utf8);
+	}
 }
 
 static void
@@ -256,7 +260,7 @@ dialog_summary_update (WorkbookControlGUI *wbcg, gboolean open_dialog)
 	/* FIXME: that's not the proper help location */
 	gnumeric_init_help_button (
 		glade_xml_get_widget (state->gui, "help_button"),
-		"summary.html");
+		GNUMERIC_HELP_LINK_SUMMARY);
 
 	dialog_summary_put (state);
 
