@@ -48,6 +48,8 @@
 #include "sheet-style.h"
 #include "style-color.h"
 
+#include <gtk/gtktable.h>
+#include <gtk/gtkradiobutton.h>
 #include <string.h>
 
 #define TABULATE_KEY "tabulate-dialog"
@@ -103,7 +105,7 @@ single_cell (Sheet *sheet, GnmExprEntry *gee)
 {
 	int col, row;
 	gboolean issingle;
-	Value *v = gnm_expr_entry_parse_as_value (gee, sheet);
+	GnmValue *v = gnm_expr_entry_parse_as_value (gee, sheet);
 
 	if (!v) return NULL;
 
