@@ -22,9 +22,11 @@
 #include <gnumeric-i18n.h>
 #include <gnumeric.h>
 #include "dialogs.h"
+#include "help.h"
 #include <glade/glade.h>
 #include <gui-util.h>
 #include <workbook-control-gui.h>
+#include <gtk/gtkradiobutton.h>
 
 #define VIEW_DIALOG_KEY "view-dialog"
 
@@ -77,8 +79,9 @@ cb_view_ok_clicked (G_GNUC_UNUSED GtkWidget *button,
 			return;  /* Just ignore */
 
 		if (!g_getenv ("GNUMERIC_MULTIHEAD")) {
+			WorkbookControlGUI *wbcg = state->wbcg;
 			gtk_widget_destroy (state->dialog);
-			gnumeric_notice (state->wbcg, GTK_MESSAGE_ERROR,
+			gnumeric_notice (wbcg, GTK_MESSAGE_ERROR,
 					 _("Multi-display support in Gnumeric has been turned "
 					   "off due to multiple bugs in GTK+, libgnomeui, "
 					   "libgnomeprintui, libbonoboui, and Gnumeric "
@@ -193,7 +196,7 @@ dialog_new_view (WorkbookControlGUI *wbcg)
 	
 	gnumeric_init_help_button (
 		glade_xml_get_widget (gui, "help_button"),
-		"view.html");
+		GNUMERIC_HELP_LINK_VIEW);
 	gnumeric_keyed_dialog (wbcg, GTK_WINDOW (state->dialog),
 			       VIEW_DIALOG_KEY);
 
