@@ -35,175 +35,11 @@
 #include "plugin-util.h"	/* for gnumeric_fopen */
 #include <string.h>
 #include <libxml/parser.h>
-#include <gal/util/e-xml-utils.h>
 
 #define CC2XML(s) ((const xmlChar *)(s))
 #define CXML2C(s) ((const char *)(s))
 
-/******************************************************************************
- * Hash table related callbacks and functions
- ******************************************************************************
- *
- * These are basically wrapper function around GHashTable ment for use by
- * the FormatTemplate.
- * The hashtable will manage its own resources, it will copy values instead
- * of using the ones passed.
- */
-
-/**
- * hash_table_destroy_entry_cb:
- * @pkey:
- * @pvalue:
- * @data:
- *
- * Callback for destroying a single key/value pair from a GHashTable
- *
- * Returns : Always TRUE
- **/
-static gboolean
-hash_table_destroy_entry_cb (gpointer pkey, gpointer pvalue,
-			     G_GNUC_UNUSED gpointer data)
-{
-	g_free ((guint *) pkey);
-	mstyle_unref ((MStyle *) pvalue);
-
-	return TRUE;
-}
-
-/**
- * hash_table_destroy:
- * @table:
- *
- * Destroy the hashtable (including the keys and values)
- *
- * Returns : Always NULL
- **/
-static GHashTable *
-hash_table_destroy (GHashTable *table)
-{
-	int size, removed;
-
-	if (table == NULL)
-		return NULL;
-
-	/*
-	 * Remove all items from the table, compare the number of
-	 * removed items to the number of items in the table
-	 * before removal as a sanity check
-	 */
-	size = g_hash_table_size (table);
-	removed = g_hash_table_foreach_remove (table, hash_table_destroy_entry_cb, NULL);
-
-	if (removed != size)
-		g_warning ("format-template.c: Not all items removed from hash table!");
-
-	g_hash_table_destroy (table);
-
-	return NULL;
-}
-
-/**
- * hash_table_create:
- *
- * Create a new hashtable for the format template
- *
- * Returns : A new hashtable
- **/
-static GHashTable *
-hash_table_create (void)
-{
-	return g_hash_table_new (g_int_hash, g_int_equal);
-}
-
-/**
- * hash_table_generate_key:
- * @row:
- * @col:
- *
- * Generate a key from row, col coordinates.
- * This key is always unique provided that row and col are
- * both below 65536 (2^16).
- *
- * Return value: The key
- **/
-static guint
-hash_table_generate_key (int row, int col)
-{
-	guint key;
-
-	key = (row << 16) + col;
-
-	return key;
-}
-
-/**
- * hash_table_lookup:
- * @table:
- * @row:
- * @col:
- *
- * Looks up a the value of a row,col pair in the hash table
- *
- * Return value: The MStyle associated with the coordinates
- **/
-static MStyle *
-hash_table_lookup (GHashTable *table, int row, int col)
-{
-	MStyle *result;
-	guint key;
-
-	key = hash_table_generate_key (row, col);
-
-	result = g_hash_table_lookup (table, &key);
-
-	return result;
-}
-
-/**
- * hash_table_insert:
- * @table:
- * @row:
- * @col:
- * @mstyle:
- * @merge_colors:
- *
- * Insert a new entry into the hashtable for row, col. Note that
- * if there is already an existing entry for those coordinates the
- * existing MStyle and the new one will be merges together to form
- * a new style
- **/
-static void
-hash_table_insert (GHashTable *table, int row, int col, MStyle *mstyle)
-{
-	MStyle *orig_value = NULL;
-	guint *orig_key = NULL;
-	guint key;
-
-	g_return_if_fail (table != NULL);
-	g_return_if_fail (mstyle != NULL);
-
-	key = hash_table_generate_key (row, col);
-
-	/*
-	 * If an entry for this col/row combination does not
-	 * yet exist then simply create a new entry in the hash table
-	 */
-	if (!g_hash_table_lookup_extended (table, &key, (gpointer *) &orig_key, (gpointer *) &orig_value)) {
-		guint *pkey = g_new (guint, 1);
-
-		*pkey = key;
-
-		g_hash_table_insert (table, pkey, mstyle_copy (mstyle));
-	} else {
-
-		/*
-		 * Overwrite any existing entry in the hashtable
-		 * FIXME : Is this the right way to handle this?
-		 */
-		mstyle_unref (orig_value);
-		g_hash_table_insert (table, orig_key, mstyle_copy (mstyle));
-	}
-}
+#define ROW_COL_KEY(row,col) GINT_TO_POINTER (row * SHEET_MAX_COLS + col)
 
 /******************************************************************************
  * FormatTemplateMember - Getters/setters and creation
@@ -221,6 +57,9 @@ format_template_member_new (void)
 {
 	TemplateMember *member;
 
+	/* Sanity check for ROW_COL_KEY.  */
+	g_assert (INT_MAX / SHEET_MAX_COLS > SHEET_MAX_ROWS);
+
 	member = g_new (TemplateMember, 1);
 
 	member->col.offset	   = member->row.offset = 0;
@@ -291,12 +130,12 @@ format_template_member_free (TemplateMember *member)
  * NOTE : This simply calculates the rectangle, it does not calculate repetitions
  *        or anything. That you'll have to do yourself :-)
  *
- * Return value: a Range containing the effective rectangle of @member
+ * Return value: a GnmRange containing the effective rectangle of @member
  **/
-static Range
-format_template_member_get_rect (TemplateMember *member, Range const *r)
+static GnmRange
+format_template_member_get_rect (TemplateMember *member, GnmRange const *r)
 {
-	Range res;
+	GnmRange res;
 
 	res.start.row = res.end.row = 0;
 	res.start.col = res.end.col = 0;
@@ -422,7 +261,7 @@ format_template_new (void)
 	ft->edges.top    = TRUE;
 	ft->edges.bottom = TRUE;
 
-	ft->table     = hash_table_create ();
+	ft->table     = g_hash_table_new_full (NULL, NULL, NULL, (GDestroyNotify)mstyle_unref);
 	ft->invalidate_hash = TRUE;
 
 	range_init (&ft->dimension, 0,0,0,0);
@@ -449,7 +288,7 @@ format_template_free (FormatTemplate *ft)
 		format_template_member_free (ptr->data);
 	g_slist_free (ft->members);
 
-	ft->table = hash_table_destroy (ft->table);
+	g_hash_table_destroy (ft->table);
 
 	g_free (ft);
 }
@@ -470,12 +309,11 @@ format_template_clone (FormatTemplate const *ft)
 
 	g_return_val_if_fail (ft != NULL, NULL);
 
-	clone = g_new0 (FormatTemplate, 1);
-
-	clone->filename    = g_strdup (ft->filename);
-	clone->author      = g_strdup (ft->author);
-	clone->name        = g_strdup (ft->name);
-	clone->description = g_strdup (ft->description);
+	clone = format_template_new ();
+	format_template_set_author (clone, ft->author);
+	format_template_set_name (clone, ft->name);
+	format_template_set_description (clone, ft->description);
+	g_free (clone->filename); clone->filename = g_strdup (ft->filename);
 
 	clone->category    = ft->category;
 
@@ -502,21 +340,26 @@ format_template_clone (FormatTemplate const *ft)
 }
 
 static void
-xml_read_format_col_row_info (FormatColRowInfo *info, xmlNodePtr parent, const xmlChar *type)
+xml_read_format_col_row_info (FormatColRowInfo *info, xmlNodePtr parent)
 {
-	xmlNode *tmp;
+	xmlNode *child;
+	int found = 0;
 
-	parent = e_xml_get_child_by_name (parent, type);
-	g_return_if_fail (parent != NULL);
-
-	tmp = e_xml_get_child_by_name (parent, CC2XML ("Placement"));
-	g_return_if_fail (tmp != NULL);
-	xml_node_get_int  (tmp, "offset", &info->offset);
-	xml_node_get_int  (tmp, "offset_gravity", &info->offset_gravity);
-
-	tmp = e_xml_get_child_by_name (parent, CC2XML ("Dimensions"));
-	g_return_if_fail (tmp != NULL);
-	xml_node_get_int (tmp, "size", &info->size);
+	for (child = parent->xmlChildrenNode; child != NULL ; child = child->next) {
+		if (xmlIsBlankNode (child) || child->name == NULL)
+			continue;
+		if (!strcmp (child->name, "Placement")) {
+			g_return_if_fail (!(found & 1));
+			xml_node_get_int  (child, "offset", &info->offset);
+			xml_node_get_int  (child, "offset_gravity", &info->offset_gravity);
+			found |= 1;
+		} else if (!strcmp (child->name, "Dimensions")) {
+			g_return_if_fail (!(found & 2));
+			xml_node_get_int (child, "size", &info->size);
+			found |= 2;
+		}
+	}
+	g_return_if_fail (found == 3);
 }
 
 static gboolean
@@ -524,31 +367,42 @@ xml_read_format_template_member (XmlParseContext *ctxt, FormatTemplate *ft, xmlN
 {
 	xmlNodePtr child;
 	TemplateMember *member;
-	int tmp;
+	int tmp, found = 0;
 
 	g_return_val_if_fail (!strcmp (tree->name, "Member"), FALSE);
 	member = format_template_member_new ();
-	xml_read_format_col_row_info (&member->col, tree, CC2XML ("Col"));
-	xml_read_format_col_row_info (&member->row, tree, CC2XML ("Row"));
 
-	child = e_xml_get_child_by_name (tree, CC2XML ("Frequency"));
-	g_return_val_if_fail (child != NULL, FALSE);
-
-	if (xml_node_get_int (child, "direction", &tmp))
-		format_template_member_set_direction (member, tmp);
-	if (xml_node_get_int (child, "repeat", &tmp))
-		format_template_member_set_repeat (member, tmp);
-	if (xml_node_get_int (child, "skip", &tmp))
-		format_template_member_set_skip (member, tmp);
-	if (xml_node_get_int (child, "edge", &tmp))
-		format_template_member_set_edge (member, tmp);
-
-	child = e_xml_get_child_by_name (tree, CC2XML ("Style"));
-	g_return_val_if_fail (child != NULL, FALSE);
-	member->mstyle = xml_read_style (ctxt, child);
+	for (child = tree->xmlChildrenNode; child != NULL ; child = child->next) {
+		if (xmlIsBlankNode (child) || child->name == NULL)
+			continue;
+		if (!strcmp (child->name, "Col"))
+			xml_read_format_col_row_info (&member->col, child);
+		else if (!strcmp (child->name, "Row"))
+			xml_read_format_col_row_info (&member->row, child);
+		else if (!strcmp (child->name, "Frequency")) {
+			if (found & 1) { g_warning ("Multiple Frequency specs"); }
+			if (xml_node_get_int (child, "direction", &tmp))
+				format_template_member_set_direction (member, tmp);
+			if (xml_node_get_int (child, "repeat", &tmp))
+				format_template_member_set_repeat (member, tmp);
+			if (xml_node_get_int (child, "skip", &tmp))
+				format_template_member_set_skip (member, tmp);
+			if (xml_node_get_int (child, "edge", &tmp))
+				format_template_member_set_edge (member, tmp);
+			found |= 1;
+		} else if (!strcmp (child->name, "Style")) {
+			if (found & 2) { g_warning ("Multiple Styles"); }
+			member->mstyle = xml_read_style (ctxt, child);
+			found |= 2;
+		}
+	}
+	if (found != 3) {
+		g_warning ("Invalid Member, missing %s", (found & 1) ? "Style" : "Frequency");
+		format_template_member_free (member);
+		return FALSE;
+	}
 
 	format_template_attach_member (ft, member);
-
 	return TRUE;
 }
 
@@ -636,7 +490,7 @@ format_template_new_from_file (char const *filename, CommandContext *cc)
 				_("Is not an autoformat template file"));
 	} else
 		gnumeric_error_read (cc,
-			_("Invalid xml file. Tree is empty ?"));
+			_("Invalid xml file. Tree is empty?"));
 
 	xmlFreeDoc (doc);
 	return ft;
@@ -806,7 +660,8 @@ format_template_compare_name (gconstpointer a, gconstpointer b)
 {
 	FormatTemplate const *ft_a = (FormatTemplate const *) a;
 	FormatTemplate const *ft_b = (FormatTemplate const *) b;
-	return strcmp (ft_a->name, ft_b->name);
+
+	return g_utf8_collate (ft_a->name, ft_b->name);
 }
 
 /******************************************************************************
@@ -839,7 +694,6 @@ format_template_filter_style (FormatTemplate *ft, MStyle *mstyle, gboolean fill_
 	 * have all their elements set
 	 */
 	if (!fill_defaults) {
-
 		if (!ft->number) {
 			mstyle_unset_element (mstyle, MSTYLE_FORMAT);
 		}
@@ -917,7 +771,7 @@ format_template_filter_style (FormatTemplate *ft, MStyle *mstyle, gboolean fill_
 /*
  * Callback used for calculating the styles
  */
-typedef void (* PCalcCallback) (FormatTemplate *ft, Range *r, MStyle *mstyle, gpointer data);
+typedef void (* PCalcCallback) (FormatTemplate *ft, GnmRange *r, MStyle *mstyle, gpointer data);
 
 /**
  * format_template_range_check:
@@ -931,7 +785,7 @@ typedef void (* PCalcCallback) (FormatTemplate *ft, Range *r, MStyle *mstyle, gp
  * Return value: TRUE if @s is big enough, FALSE if not.
  **/
 static gboolean
-format_template_range_check (FormatTemplate *ft, Range const *r,
+format_template_range_check (FormatTemplate *ft, GnmRange const *r,
 			     CommandContext *optional_cc)
 {
 	GSList *iterator;
@@ -944,7 +798,7 @@ format_template_range_check (FormatTemplate *ft, Range const *r,
 	iterator = ft->members;
 	while (iterator) {
 		TemplateMember *member = iterator->data;
-		Range range = format_template_member_get_rect (member, r);
+		GnmRange range = format_template_member_get_rect (member, r);
 
 		if (!range_valid (&range)) {
 			int diff_col = (range.start.col - range.end.col);
@@ -1006,14 +860,13 @@ static FormatTemplate *
 format_template_transform_edges (FormatTemplate const *origft)
 {
 	FormatTemplate *ft;
-	GSList *iterator;
+	GSList *ptr0, *ptr1;
 
 	g_return_val_if_fail (origft != NULL, NULL);
 
 	ft = format_template_clone (origft);
-	iterator = ft->members;
-	while (iterator) {
-		TemplateMember *member = iterator->data;
+	for (ptr0 = ft->members; ptr0 != NULL ; ptr0 = ptr0->next) {
+		TemplateMember *member = ptr0->data;
 
 		gboolean left   = FALSE;
 		gboolean right  = FALSE;
@@ -1036,11 +889,9 @@ format_template_transform_edges (FormatTemplate const *origft)
 		}
 
 		if (left || right || top || bottom) {
-			GSList *subiterator = ft->members;
-			GSList *tmp = NULL;
 
-			while (subiterator) {
-				TemplateMember *submember = subiterator->data;
+			for (ptr1 = ft->members; ptr1 != NULL ; ptr1 = ptr1->next) {
+				TemplateMember *submember = ptr1->data;
 
 				if (left
 				    && submember->col.offset_gravity == member->col.offset_gravity) {
@@ -1075,15 +926,11 @@ format_template_transform_edges (FormatTemplate const *origft)
 					else if (submember->direction != FREQ_DIRECTION_NONE)
 						submember->edge = 0;
 				}
-
-				subiterator = g_slist_next (subiterator);
 			}
 
-			tmp = g_slist_next (iterator);
-			ft->members = g_slist_remove (ft->members, iterator->data);
-			iterator = tmp;
-		} else
-			iterator = g_slist_next (iterator);
+			format_template_member_free (ptr0->data);
+			ft->members = g_slist_remove (ft->members, ptr0->data);
+		}
 	}
 	return ft;
 }
@@ -1101,7 +948,7 @@ format_template_transform_edges (FormatTemplate const *origft)
  *
  **/
 static void
-format_template_calculate (FormatTemplate *origft, Range const *r, PCalcCallback pc, gpointer cb_data)
+format_template_calculate (FormatTemplate *origft, GnmRange const *r, PCalcCallback pc, gpointer cb_data)
 {
 	FormatTemplate *ft = origft;
 	GSList *iterator;
@@ -1118,14 +965,14 @@ format_template_calculate (FormatTemplate *origft, Range const *r, PCalcCallback
 	while (iterator) {
 		TemplateMember *member = iterator->data;
 		MStyle const *mstyle = member->mstyle;
-		Range range = format_template_member_get_rect (member, r);
+		GnmRange range = format_template_member_get_rect (member, r);
 
 		if (member->direction == FREQ_DIRECTION_NONE)
 			pc (ft, &range, mstyle_copy (mstyle), cb_data);
 
 		else if (member->direction == FREQ_DIRECTION_HORIZONTAL) {
 			int col_repeat = member->repeat;
-			Range hr = range;
+			GnmRange hr = range;
 
 			while (col_repeat != 0) {
 				pc (ft, &hr, mstyle_copy (mstyle), cb_data);
@@ -1145,7 +992,7 @@ format_template_calculate (FormatTemplate *origft, Range const *r, PCalcCallback
 			}
 		} else if (member->direction == FREQ_DIRECTION_VERTICAL) {
 			int row_repeat = member->repeat;
-			Range vr = range;
+			GnmRange vr = range;
 
 			while (row_repeat != 0) {
 				pc (ft, &vr, mstyle_copy (mstyle), cb_data);
@@ -1177,7 +1024,7 @@ format_template_calculate (FormatTemplate *origft, Range const *r, PCalcCallback
  ******************************************************************************/
 
 static void
-cb_format_hash_style (FormatTemplate *ft, Range *r, MStyle *mstyle, GHashTable *table)
+cb_format_hash_style (FormatTemplate *ft, GnmRange *r, MStyle *mstyle, GHashTable *table)
 {
 	int row, col;
 
@@ -1188,8 +1035,8 @@ cb_format_hash_style (FormatTemplate *ft, Range *r, MStyle *mstyle, GHashTable *
 
 	for (row = r->start.row; row <= r->end.row; row++) {
 		for (col = r->start.col; col <= r->end.col; col++) {
-
-			hash_table_insert (table, row, col, mstyle);
+			g_hash_table_insert (table, ROW_COL_KEY (row, col),
+					     mstyle_copy (mstyle));
 		}
 	}
 
@@ -1209,12 +1056,11 @@ cb_format_hash_style (FormatTemplate *ft, Range *r, MStyle *mstyle, GHashTable *
 static void
 format_template_recalc_hash (FormatTemplate *ft)
 {
-	Range r;
+	GnmRange r;
 
 	g_return_if_fail (ft != NULL);
 
-	ft->table = hash_table_destroy (ft->table);
-	ft->table = hash_table_create ();
+	g_hash_table_foreach_remove (ft->table, (GHRFunc)g_direct_hash /* :-) */, NULL);
 
 	r = ft->dimension;
 
@@ -1246,8 +1092,6 @@ format_template_recalc_hash (FormatTemplate *ft)
 MStyle *
 format_template_get_style (FormatTemplate *ft, int row, int col)
 {
-	MStyle *mstyle;
-
 	g_return_val_if_fail (ft != NULL, NULL);
 	g_return_val_if_fail (ft->table != NULL, NULL);
 
@@ -1256,14 +1100,11 @@ format_template_get_style (FormatTemplate *ft, int row, int col)
 	 * then refill it
 	 */
 	if (ft->invalidate_hash) {
-
 		ft->invalidate_hash = FALSE;
 		format_template_recalc_hash (ft);
 	}
 
-	mstyle = hash_table_lookup (ft->table, row, col);
-
-	return mstyle;
+	return g_hash_table_lookup (ft->table, ROW_COL_KEY (row, col));
 }
 
 
@@ -1273,7 +1114,7 @@ format_template_get_style (FormatTemplate *ft, int row, int col)
  ******************************************************************************/
 
 static void
-cb_format_sheet_style (FormatTemplate *ft, Range *r, MStyle *mstyle, Sheet *sheet)
+cb_format_sheet_style (FormatTemplate *ft, GnmRange *r, MStyle *mstyle, Sheet *sheet)
 {
 	g_return_if_fail (ft != NULL);
 	g_return_if_fail (r != NULL);
@@ -1336,8 +1177,7 @@ format_template_set_name (FormatTemplate *ft, char const *name)
 	g_return_if_fail (ft != NULL);
 	g_return_if_fail (name != NULL);
 
-	if (ft->name)
-		g_free (ft->name);
+	g_free (ft->name);
 	ft->name = g_strdup (name);
 }
 
@@ -1347,8 +1187,7 @@ format_template_set_author (FormatTemplate *ft, char const *author)
 	g_return_if_fail (ft != NULL);
 	g_return_if_fail (author != NULL);
 
-	if (ft->author)
-		g_free (ft->author);
+	g_free (ft->author);
 	ft->author = g_strdup (author);
 }
 
@@ -1358,7 +1197,6 @@ format_template_set_description (FormatTemplate *ft, char const *description)
 	g_return_if_fail (ft != NULL);
 	g_return_if_fail (description != NULL);
 
-	if (ft->description)
-		g_free (ft->description);
+	g_free (ft->description);
 	ft->description = g_strdup (description);
 }
