@@ -87,13 +87,13 @@ struct _FormatTemplate {
 		gboolean top;
 		gboolean bottom;
 	} edges;
-	
+
 /* <private> */
 	/* pre-calculate styles */
 	GHashTable *table;
 	gboolean invalidate_hash;
 
-	Range dimension;
+	GnmRange dimension;
 };
 
 typedef struct {
