@@ -75,10 +75,10 @@ StyleFormat   *style_format_default_money	(void);
 #define style_format_is_general(sf) ((sf)->family == FMT_GENERAL)
 #define style_format_is_text(sf) ((sf)->family == FMT_TEXT)
 
-char  *format_value   (StyleFormat const *format, Value const *value, StyleColor **color,
+char  *format_value   (StyleFormat const *format, GnmValue const *value, StyleColor **color,
 		       double col_width, GnmDateConventions const *date_conv);
 void   format_value_gstring (GString *result, StyleFormat const *format,
-			     Value const *value, StyleColor **color,
+			     GnmValue const *value, StyleColor **color,
 			     double col_width, GnmDateConventions const *date_conv);
 
 void   format_color_init     (void);
@@ -109,6 +109,7 @@ char        format_get_arg_sep      (void);
 char        format_get_col_sep      (void);
 char const *format_get_thousand     (void);
 char const *format_get_decimal      (void);
+char const *format_boolean          (gboolean b);
 
 void number_format_init (void);
 void number_format_shutdown (void);
