@@ -2,7 +2,7 @@
  * func-builtin.c:  Built in functions.
  *
  * Authors:
- *   Morten Welinder (terra@diku.dk)
+ *   Morten Welinder (terra@gnome.org)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,7 +47,7 @@ static const char *help_sum = {
 	   "@SEEALSO=AVERAGE, COUNT")
 };
 
-Value *
+GnmValue *
 gnumeric_sum (FunctionEvalInfo *ei, GnmExprList *nodes)
 {
 	return float_range_function (nodes, ei,
@@ -86,7 +86,7 @@ range_bogusproduct (const gnm_float *xs, int n, gnm_float *res)
 		return range_product (xs, n, res);
 }
 
-Value *
+GnmValue *
 gnumeric_product (FunctionEvalInfo *ei, GnmExprList *nodes)
 {
 	return float_range_function (nodes, ei,
@@ -104,7 +104,7 @@ static const char *help_gnumeric_version = {
 	   "@SYNTAX=GNUMERIC_VERSION()\n"
 
 	   "@DESCRIPTION="
-	   "GNUMERIC_VERSION return the version of gnumeric as a string."
+	   "GNUMERIC_VERSION returns the version of gnumeric as a string."
 
 	   "\n"
 	   "@EXAMPLES=\n"
@@ -113,15 +113,15 @@ static const char *help_gnumeric_version = {
 	   "@SEEALSO=")
 };
 
-static Value *
-gnumeric_version (FunctionEvalInfo *ei, Value *argv [])
+static GnmValue *
+gnumeric_version (FunctionEvalInfo *ei, GnmValue *argv [])
 {
 	return value_new_string (GNUMERIC_VERSION);
 }
 
 /***************************************************************************/
 
-static const char *mathcatname = N_("Maths / Trig.");
+static const char *mathcatname = N_("Mathematics");
 static GSList *mathfuncs = NULL;
 
 static const char *gnumericcatname = N_("Gnumeric");
