@@ -6,7 +6,7 @@
  * Author:
  *  Miguel de Icaza (miguel@gnu.org)
  *  Michael Meeks   (mmeeks@gnu.org)
- *  Morten Welinder (terra@diku.dk)
+ *  Morten Welinder (terra@gnome.org)
  *  Jody Goldberg   (jody@gnome.org)
  */
 #include <gnumeric-config.h>
@@ -97,6 +97,7 @@ void
 function_dump_defs (char const *filename, gboolean as_def)
 {
 	FILE *output_file;
+	char *up;
 	unsigned i;
 	GPtrArray *ordered;
 	GnmFuncGroup const *group = NULL;
@@ -124,7 +125,8 @@ function_dump_defs (char const *filename, gboolean as_def)
 	for (i = 0; i < ordered->len; i++) {
 		GnmFunc const *fd = g_ptr_array_index (ordered, i);
 		if (as_def) {
-			fprintf (output_file, "%s\n\n", _(fd->help));
+			fprintf (output_file, "@CATEGORY=%s\n%s\n\n",
+				 _(fd->fn_group->display_name->str), _(fd->help));
 		} else {
 			static struct {
 				char const *name;
@@ -153,9 +155,11 @@ function_dump_defs (char const *filename, gboolean as_def)
 				group = fd->fn_group;
 				fprintf (output_file, "<tr><td><h1>%s</h1></td><td><b>Function</b></td><td><b>Implementation</b></td><td><b>Testing</b></td></tr>\n", group->display_name->str);
 			}
+			up = g_ascii_strup (fd->name, -1);
 			fprintf (output_file, "<tr><td></td>\n");
 			fprintf (output_file,
-"    <td><a href =\"doc/gnumeric-%s.html\">%s</a></td>\n", fd->name, fd->name);
+"    <td><a href =\"doc/gnumeric-%s.html\">%s</a></td>\n", up, fd->name);
+			g_free (up);
 			fprintf (output_file,
 "    <td bgcolor=#%s><a href=\"mailto:gnumeric-list@gnome.org?subject=Re: %s implementation\">%s</a></td>\n",
 implementation[fd->impl_status].colour_str, fd->name, implementation[fd->impl_status].name);
@@ -180,8 +184,8 @@ gnm_func_group_free (GnmFuncGroup *fn_group)
 	g_return_if_fail (fn_group != NULL);
 	g_return_if_fail (fn_group->functions == NULL);
 
-	string_unref (fn_group->internal_name);
-	string_unref (fn_group->display_name);
+	gnm_string_unref (fn_group->internal_name);
+	gnm_string_unref (fn_group->display_name);
 	g_free (fn_group);
 }
 
@@ -219,12 +223,12 @@ gnm_func_group_fetch_with_translation (char const *name,
 
 	if (l == NULL) {
 		cat = g_new (GnmFuncGroup, 1);
-		cat->internal_name = string_get (name);
+		cat->internal_name = gnm_string_get (name);
 		if (translation != NULL) {
-			cat->display_name = string_get (translation);
+			cat->display_name = gnm_string_get (translation);
 			cat->has_translation = TRUE;
 		} else {
-			cat->display_name = string_get (name);
+			cat->display_name = gnm_string_get (name);
 			cat->has_translation = FALSE;
 		}
 		cat->functions = NULL;
@@ -232,8 +236,8 @@ gnm_func_group_fetch_with_translation (char const *name,
 		             categories, cat, &function_category_compare);
 	} else if (translation != NULL && translation != name &&
 	           !cat->has_translation) {
-		string_unref (cat->display_name);
-		cat->display_name = string_get (translation);
+		gnm_string_unref (cat->display_name);
+		cat->display_name = gnm_string_get (translation);
 		cat->has_translation = TRUE;
 		g_list_remove_link (categories, l);
 		g_list_free_1 (l);
@@ -289,7 +293,7 @@ extract_arg_types (GnmFunc *def)
 	def->fn.args.arg_types[i] = 0;
 }
 
-static Value *
+static GnmValue *
 error_function_no_full_info (FunctionEvalInfo *ei, GnmExprList *expr_node_list)
 {
 	return value_new_error (ei->pos, _("Function implementation not available."));
@@ -459,7 +463,7 @@ gnm_func_add (GnmFuncGroup *fn_group,
 }
 
 /* Handle unknown functions on import without losing their names */
-static Value *
+static GnmValue *
 unknownFunctionHandler (FunctionEvalInfo *ei, GnmExprList *expr_node_list)
 {
 	return value_new_error_NAME (ei->pos);
@@ -681,6 +685,8 @@ function_def_get_arg_type_string (GnmFunc const *fn_def,
 		return _("Cell Range");
 	case 'A':
 		return _("Area");
+	case 'B':
+		return _("Scalar or Blank");
 	case 'E':
 		return _("Scalar or Error");
 	case 'S':
@@ -742,7 +748,7 @@ function_def_get_arg_name (GnmFunc const *fn_def,
 /* ------------------------------------------------------------------------- */
 
 static inline void
-free_values (Value **values, int top)
+free_values (GnmValue **values, int top)
 {
 	int i;
 
@@ -761,14 +767,14 @@ free_values (Value **values, int top)
  *
  * Returns the result.
  **/
-Value *
+GnmValue *
 function_call_with_list (FunctionEvalInfo *ei, GnmExprList *l,
 			 GnmExprEvalFlags flags)
 {
 	GnmFunc const *fn_def;
-	int	  argc, i, optional, iter_count, iter_width = 0, iter_height = 0;
+	int	  argc, i, iter_count, iter_width = 0, iter_height = 0;
 	char	  arg_type;
-	Value	 **args, *tmp = NULL;
+	GnmValue	 **args, *tmp = NULL;
 	GnmExpr  *expr;
 	int 	 *iter_item = NULL;
 
@@ -791,27 +797,25 @@ function_call_with_list (FunctionEvalInfo *ei, GnmExprList *l,
 					_("Invalid number of arguments"));
 	}
 
-	optional = 0;
-	args = g_alloca (sizeof (Value *) * fn_def->fn.args.max_args);
+	args = g_alloca (sizeof (GnmValue *) * fn_def->fn.args.max_args);
 	iter_count = (flags & GNM_EXPR_EVAL_PERMIT_NON_SCALAR) ? 0 : -1;
 
 	for (i = 0; l; l = l->next, ++i) {
 		arg_type = fn_def->fn.args.arg_types[i];
-		expr = l->data;
-
-		if (i >= fn_def->fn.args.min_args)
-			optional = GNM_EXPR_EVAL_PERMIT_EMPTY;
+		/* expr is always non-null, missing args are encoded as
+		 * const = empty */
+		expr = l->data; 
 
 		if (arg_type == 'A' || arg_type == 'r') {
 			if (expr->any.oper == GNM_EXPR_OP_CELLREF) {
-				CellRef r;
+				GnmCellRef r;
 				cellref_make_abs (&r, &expr->cellref.ref, ei->pos);
 				args[i] = value_new_cellrange_unsafe (&r, &r);
 				/* TODO decide on the semantics of these argument types */
 #warning do we need to force an eval here ?
 			} else {
 				tmp = args[i] = gnm_expr_eval (expr, ei->pos,
-					optional | GNM_EXPR_EVAL_PERMIT_NON_SCALAR);
+					GNM_EXPR_EVAL_PERMIT_NON_SCALAR);
 				if (tmp->type == VALUE_CELLRANGE) {
 					cellref_make_abs (&tmp->v_range.cell.a,
 							  &tmp->v_range.cell.a,
@@ -828,10 +832,12 @@ function_call_with_list (FunctionEvalInfo *ei, GnmExprList *l,
 		}
 
 		/* force scalars whenever we are certain */
-		tmp = args[i] = gnm_expr_eval (expr, ei->pos, optional |
+		tmp = args[i] = gnm_expr_eval (expr, ei->pos,
 		       ((iter_count >= 0 || arg_type == '?')
 			       ? GNM_EXPR_EVAL_PERMIT_NON_SCALAR
-			       : GNM_EXPR_EVAL_SCALAR_NON_EMPTY));
+			       : ((arg_type == 'B')
+					? GNM_EXPR_EVAL_PERMIT_EMPTY
+					: GNM_EXPR_EVAL_SCALAR_NON_EMPTY)));
 
 		if (tmp == NULL ||	/* Optional arguments can be empty */
 		    arg_type == '?')	/* '?' arguments are unrestriced */
@@ -855,8 +861,10 @@ function_call_with_list (FunctionEvalInfo *ei, GnmExprList *l,
 				iter_width = value_area_get_width (tmp, ei->pos);
 				iter_height = value_area_get_height (tmp, ei->pos);
 			}
-			iter_item[iter_count] = iter_count;
-			iter_count++;
+			iter_item [iter_count++] = i;
+
+			/* no need to check type, we would fail comparing a range against a "b, f, or s" */
+			continue;
 		}
 
 		/* All of these argument types must be scalars */
@@ -902,6 +910,7 @@ function_call_with_list (FunctionEvalInfo *ei, GnmExprList *l,
 			}
 			break;
 
+		case 'B': /* nothing necessary */
 		case 'E': /* nothing necessary */
 			break;
 
@@ -911,16 +920,16 @@ function_call_with_list (FunctionEvalInfo *ei, GnmExprList *l,
 			break;
 		}
 	}
-
+ 
 	while (i < fn_def->fn.args.max_args)
 		args [i++] = NULL;
 
 	if (iter_item != NULL) {
 		int x, y;
-		Value *res = value_new_array_empty (iter_width, iter_height);
-		Value const *elem, *err;
-		Value **iter_vals = g_alloca (sizeof (Value *) * iter_count);
-		Value **iter_args = g_alloca (sizeof (Value *) * iter_count);
+		GnmValue *res = value_new_array_empty (iter_width, iter_height);
+		GnmValue const *elem, *err;
+		GnmValue **iter_vals = g_alloca (sizeof (GnmValue *) * iter_count);
+		GnmValue **iter_args = g_alloca (sizeof (GnmValue *) * iter_count);
 
 		/* collect the args we will iterate on */
 		for (i = 0 ; i < iter_count; i++)
@@ -982,9 +991,9 @@ function_call_with_list (FunctionEvalInfo *ei, GnmExprList *l,
  * Use this to invoke a register function: the only drawback is that
  * you have to compute/expand all of the values to use this
  */
-Value *
+GnmValue *
 function_call_with_values (EvalPos const *ep, char const *fn_name,
-			   int argc, Value *values [])
+			   int argc, GnmValue *values [])
 {
 	GnmFunc *fn_def;
 
@@ -999,13 +1008,13 @@ function_call_with_values (EvalPos const *ep, char const *fn_name,
 	return function_def_call_with_values (ep, fn_def, argc, values);
 }
 
-Value *
+GnmValue *
 function_def_call_with_values (EvalPos const *ep,
                                GnmFunc const *fn_def,
                                gint    argc,
-                               Value  *values [])
+                               GnmValue  *values [])
 {
-	Value *retval;
+	GnmValue *retval;
 	GnmExprFunction	ef;
 	FunctionEvalInfo fs;
 
@@ -1061,12 +1070,12 @@ typedef struct {
  * Helper routine used by the function_iterate_do_value routine.
  * Invoked by the sheet cell range iterator.
  */
-static Value *
+static GnmValue *
 cb_iterate_cellrange (Sheet *sheet, int col, int row,
 		      Cell *cell, gpointer user_data)
 {
 	IterateCallbackClosure *data = user_data;
-	Value *res;
+	GnmValue *res;
 	EvalPos ep;
 
 	if (cell == NULL) {
@@ -1097,15 +1106,15 @@ cb_iterate_cellrange (Sheet *sheet, int col, int row,
  *
  * Helper routine for function_iterate_argument_values.
  */
-Value *
+GnmValue *
 function_iterate_do_value (EvalPos const *ep,
 			   FunctionIterateCB  callback,
 			   gpointer	 closure,
-			   Value	*value,
+			   GnmValue	*value,
 			   gboolean      strict,
 			   CellIterFlags iter_flags)
 {
-	Value *res = NULL;
+	GnmValue *res = NULL;
 
 	switch (value->type){
 	case VALUE_ERROR:
@@ -1165,21 +1174,21 @@ function_iterate_do_value (EvalPos const *ep,
  * @strict:           If TRUE, the function is considered "strict".  This means
  *                   that if an error value occurs as an argument, the iteration
  *                   will stop and that error will be returned.  If FALSE, an
- *                   error will be passed on to the callback (as a Value *
+ *                   error will be passed on to the callback (as a GnmValue *
  *                   of type VALUE_ERROR).
  * @iter_flags:
  *
  * Return value:
  *    NULL            : if no errors were reported.
- *    Value *         : if an error was found during strict evaluation
+ *    GnmValue *         : if an error was found during strict evaluation
  *    VALUE_TERMINATE : if the callback requested termination of the iteration.
  *
  * This routine provides a simple way for internal functions with variable
  * number of arguments to be written: this would iterate over a list of
  * expressions (expr_node_list) and will invoke the callback for every
- * Value found on the list (this means that ranges get properly expaned).
+ * GnmValue found on the list (this means that ranges get properly expaned).
  */
-Value *
+GnmValue *
 function_iterate_argument_values (EvalPos const		*ep,
 				  FunctionIterateCB	 callback,
 				  void			*callback_closure,
@@ -1187,12 +1196,12 @@ function_iterate_argument_values (EvalPos const		*ep,
 				  gboolean		 strict,
 				  CellIterFlags		 iter_flags)
 {
-	Value * result = NULL;
+	GnmValue * result = NULL;
 
 	for (; result == NULL && expr_node_list;
 	     expr_node_list = expr_node_list->next) {
 		GnmExpr const *expr = expr_node_list->data;
-		Value *val;
+		GnmValue *val;
 
 		if (iter_flags & CELL_ITER_IGNORE_SUBTOTAL &&
 		    gnm_expr_containts_subtotal (expr))
