@@ -30,6 +30,19 @@
 #include <widgets/widget-color-combo.h>
 #include <widgets/preview-file-selection.h>
 #include <glade/glade.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkmain.h>
+#include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtkeventbox.h>
+#include <gtk/gtkradiobutton.h>
+#include <gtk/gtkalignment.h>
+#include <gtk/gtkstock.h>
+#include <gtk/gtkimage.h>
+#include <gtk/gtkframe.h>
+#include <gtk/gtkimagemenuitem.h>
+#include <gtk/gtkbbox.h>
+#include <atk/atkrelation.h>
+#include <atk/atkrelationset.h>
 
 #ifdef WITH_BONOBO
 #	include <bonobo.h>
@@ -428,7 +441,6 @@ cb_free_keyed_dialog_context (KeyedDialogContext *ctxt)
 		return;
 	ctxt->freed = TRUE;
 
-	g_return_if_fail (g_object_get_data (G_OBJECT (ctxt->wbcg), ctxt->key));
 	/*
 	 * One of these causes a recursive call which will do nothing due to
 	 * ->freed.
@@ -1121,7 +1133,7 @@ gboolean
 entry_to_float_with_format (GtkEntry *entry, gnm_float *the_float, gboolean update,
 			    StyleFormat *format)
 {
-	Value *value = format_match_number (gtk_entry_get_text (entry), format, NULL);
+	GnmValue *value = format_match_number (gtk_entry_get_text (entry), format, NULL);
 
 	if ((value == NULL) || !VALUE_IS_NUMBER (value)) {
 		*the_float = 0.0;
@@ -1150,7 +1162,7 @@ entry_to_float_with_format (GtkEntry *entry, gnm_float *the_float, gboolean upda
 gboolean
 entry_to_int (GtkEntry *entry, gint *the_int, gboolean update)
 {
-	Value *value = format_match_number (gtk_entry_get_text (entry), NULL, NULL);
+	GnmValue *value = format_match_number (gtk_entry_get_text (entry), NULL, NULL);
 
 	if ((value == NULL) || !(value->type == VALUE_INTEGER)) {
 		*the_int = 0;
@@ -1176,7 +1188,7 @@ entry_to_int (GtkEntry *entry, gint *the_int, gboolean update)
 void
 float_to_entry (GtkEntry *entry, gnm_float the_float)
 {
-	Value *val  = value_new_float (the_float);
+	GnmValue *val  = value_new_float (the_float);
 	char  *text = format_value (NULL, val, NULL, 16, NULL);
 	if (text != NULL) {
 		gtk_entry_set_text (entry, text);
@@ -1196,7 +1208,7 @@ float_to_entry (GtkEntry *entry, gnm_float the_float)
 void
 int_to_entry (GtkEntry *entry, gint the_int)
 {
-	Value *val  = value_new_int (the_int);
+	GnmValue *val  = value_new_int (the_int);
 	char  *text = format_value (NULL, val, NULL, 16, NULL);
 	if (text != NULL) {
 		gtk_entry_set_text (entry, text);
