@@ -5,19 +5,25 @@
 #include "error-info.h"
 #include "command-context.h"
 #include "gutils.h"
-#include <gtk/gtk.h>
+#include <gtk/gtkbutton.h>
+#include <gtk/gtkcombo.h>
+#include <gtk/gtkfilesel.h>
+#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtkmenu.h>
+#include <gtk/gtktoolbar.h>
+#include <gtk/gtktextview.h>
+#include <gtk/gtkentry.h>
 #include <glade/glade-xml.h>
 
-#if 1 /* go away when we switch to eggmenu */
-#include <libgnomeui/libgnomeui.h>
-#endif
-
 gboolean   gnumeric_dialog_question_yes_no (WorkbookControlGUI *wbcg,
                                             const gchar *message,
                                             gboolean default_answer);
-gboolean   gnumeric_dialog_file_selection (WorkbookControlGUI *wbcg, GtkFileSelection *fsel);
-gboolean   gnumeric_dialog_dir_selection (WorkbookControlGUI *wbcg, GtkFileSelection *fsel);
-void       gnumeric_notice (WorkbookControlGUI *wbcg, GtkMessageType type, const char *str);
+gboolean   gnumeric_dialog_file_selection (WorkbookControlGUI *wbcg, 
+					   GtkFileSelection *fsel);
+gboolean   gnumeric_dialog_dir_selection (WorkbookControlGUI *wbcg, 
+					  GtkFileSelection *fsel);
+void       gnumeric_notice (WorkbookControlGUI *wbcg, GtkMessageType type, 
+			    const char *str);
 void       gnumeric_notice_nonmodal (GtkWindow *parent, GtkWidget **ref,
 				     GtkMessageType type, char const *str);
 
@@ -59,9 +65,6 @@ int gnumeric_glade_group_value (GladeXML *gui, const char *group[]);
 /* Use this on menus that are popped up */
 void gnumeric_popup_menu (GtkMenu *menu, GdkEventButton *event);
 
-/* Scroll the viewing area of the list to the given row */
-void gnumeric_clist_moveto (/*GtkCList*/ void *clist, gint row);
-
 /*
  * Pseudo-tool-tip support code.
  */
@@ -98,7 +101,7 @@ void gnumeric_create_popup_menu (GnumericPopupMenuElement const *elements,
 
 StyleColor *color_combo_get_style_color (GtkWidget *color_combo);
 
-GtkWidget *gnumeric_toolbar_new (WorkbookControlGUI *wbcg, GnomeUIInfo *info,
+GtkWidget *gnumeric_toolbar_new (WorkbookControlGUI *wbcg, gpointer info,
 				  char const *name, gint band_num, gint band_position, gint offset);
 GtkWidget *gnumeric_toolbar_get_widget (GtkToolbar *toolbar, int pos);
 
@@ -126,31 +129,17 @@ void	 int_to_entry	(GtkEntry *entry, gint the_int);
 GtkWidget *gnumeric_load_image  (char const *name);
 GdkPixbuf *gnumeric_load_pixbuf (char const *name);
 
-void gnm_setup_label_atk (GtkLabel *label, GtkWidget *target);
+GdkPixbuf *gnm_pixbuf_tile (const GdkPixbuf *src, int w, int h);
+
+void gnm_setup_label_atk (GtkWidget *label, GtkWidget *target);
 
 int gnm_measure_string (PangoContext *context, const PangoFontDescription *font_desc, const char *str);
 
 void gnm_link_button_and_entry (GtkWidget *button, GtkWidget *entry);
 
-/* Refugees from GAL.  */
-typedef enum {
-	GNM_CURSOR_FAT_CROSS,
-	GNM_CURSOR_THIN_CROSS,
-	GNM_CURSOR_ARROW,
-	GNM_CURSOR_MOVE,
-	GNM_CURSOR_ZOOM_IN,
-	GNM_CURSOR_ZOOM_OUT,
-	GNM_CURSOR_SIZE_X,
-	GNM_CURSOR_SIZE_Y,
-	GNM_CURSOR_SIZE_TL,
-	GNM_CURSOR_SIZE_TR,
-	GNM_CURSOR_PRESS,
-	GNM_CURSOR_HAND_OPEN,
-	GNM_CURSOR_HAND_CLOSED,
-	GNM_CURSOR_XTERM,
-	GNM_CURSOR_NUM_CURSORS
-} GnmCursorType;
-void gnm_cursor_set_widget (GtkWidget *w, GnmCursorType c);
+void gnm_widget_set_cursor_type (GtkWidget *w, GdkCursorType ct);
+void gnm_widget_set_cursor (GtkWidget *w, GdkCursor *ct);
+GdkCursor *gnm_fat_cross_cursor (GdkDisplay *display);
 
 GtkWidget * gnumeric_button_new_with_stock_image (const gchar* text, const gchar* stock_id);
 GtkWidget * gnumeric_dialog_add_button (GtkDialog *dialog, const gchar* text, const gchar* stock_id,
@@ -161,4 +150,7 @@ GtkWidget * gnumeric_message_dialog_new (GtkWindow * parent,
 					 gchar const * primary_message,
 					 gchar const * secondary_message);
 
+GdkPixbuf* gnm_pixbuf_intelligent_scale (GdkPixbuf *pixbuf, 
+					 guint width, guint height);
+
 #endif /* GNUMERIC_GUI_UTIL_H */
