@@ -25,6 +25,8 @@
 #include <gtk/gtkprogressbar.h>
 #include <gtk/gtkvbox.h>
 #include <gtk/gtkwindow.h>
+#include <gtk/gtkimage.h>
+#include <gtk/gtkframe.h>
 #include <stdlib.h>
 
 extern int gnumeric_no_splash;
