@@ -49,7 +49,7 @@
 static void
 col_name_internal (GString *target, int col)
 {
-	static const int steps[] = {
+	static int const steps[] = {
 		26,
 		26 * 26,
 		26 * 26 * 26,
@@ -186,7 +186,7 @@ row_parse (char const *str, int *res, unsigned char *relative)
 /***************************************************************************/
 
 inline static int
-cellref_abs_col (CellRef const *ref, ParsePos const *pp)
+cellref_abs_col (GnmCellRef const *ref, ParsePos const *pp)
 {
 	int col = (ref->col_relative) ? pp->eval.col + ref->col : ref->col;
 
@@ -198,7 +198,7 @@ cellref_abs_col (CellRef const *ref, ParsePos const *pp)
 }
 
 inline static int
-cellref_abs_row (CellRef const *ref, ParsePos const *pp)
+cellref_abs_row (GnmCellRef const *ref, ParsePos const *pp)
 {
 	int row = (ref->row_relative) ? pp->eval.row + ref->row : ref->row;
 
@@ -220,8 +220,8 @@ cellref_abs_row (CellRef const *ref, ParsePos const *pp)
  * suppress the addition of the sheetname for non-local references.
  **/
 void
-cellref_as_string (GString *target, const GnmExprConventions *conv,
-		   CellRef const *cell_ref,
+cellref_as_string (GString *target, GnmExprConventions const *conv,
+		   GnmCellRef const *cell_ref,
 		   ParsePos const *pp, gboolean no_sheetname)
 {
 	int col, row;
@@ -277,10 +277,10 @@ cellref_as_string (GString *target, const GnmExprConventions *conv,
  *
  **/
 void
-rangeref_as_string (GString *target, const GnmExprConventions *conv,
-		    RangeRef const *ref, ParsePos const *pp)
+rangeref_as_string (GString *target, GnmExprConventions const *conv,
+		    GnmRangeRef const *ref, ParsePos const *pp)
 {
-	Range r;
+	GnmRange r;
 
 	r.start.col = cellref_abs_col (&ref->a, pp);
 	r.end.col   = cellref_abs_col (&ref->b, pp);
@@ -344,7 +344,7 @@ rangeref_as_string (GString *target, const GnmExprConventions *conv,
 }
 
 static char const *
-cellref_a1_get (CellRef *out, char const *in, CellPos const *pos)
+cellref_a1_get (GnmCellRef *out, char const *in, GnmCellPos const *pos)
 {
 	int col;
 	int row;
@@ -414,7 +414,7 @@ r1c1_get_item (int *num, unsigned char *rel, char const * *in)
 }
 
 static char const *
-cellref_r1c1_get (CellRef *out, char const *in, CellPos const *pos)
+cellref_r1c1_get (GnmCellRef *out, char const *in, GnmCellPos const *pos)
 {
 	out->row_relative = FALSE;
 	out->col_relative = FALSE;
@@ -443,7 +443,7 @@ cellref_r1c1_get (CellRef *out, char const *in, CellPos const *pos)
 
 /**
  * cellref_parse:
- * @out: destination CellRef
+ * @out: destination GnmCellRef
  * @in: reference description text, no leading
  *      whitespace allowed.
  * @pos:
@@ -454,7 +454,7 @@ cellref_r1c1_get (CellRef *out, char const *in, CellPos const *pos)
  * Return value: a pointer to the character following the cellref.
  **/
 char const *
-cellref_parse (CellRef *out, char const *in, CellPos const *pos)
+cellref_parse (GnmCellRef *out, char const *in, GnmCellPos const *pos)
 {
 	char const *res;
 
@@ -484,7 +484,7 @@ cell_coord_name (int col, int row)
 }
 
 char const *
-cellpos_as_string (CellPos const *pos)
+cellpos_as_string (GnmCellPos const *pos)
 {
 	g_return_val_if_fail (pos != NULL, "ERROR");
 
@@ -511,7 +511,7 @@ cell_name (Cell const *cell)
  * (In the strict case, that would be a pointer to the \0 or NULL.)
  */
 char const *
-cellpos_parse (char const *cell_str, CellPos *res, gboolean strict)
+cellpos_parse (char const *cell_str, GnmCellPos *res, gboolean strict)
 {
 	unsigned char dummy_relative;
 
@@ -579,17 +579,17 @@ gnm_expr_char_start_p (char const * c)
  *
  * @pos : If the string looks like an expression parse it at this location.
  * @text: The text to be parsed.
- * @val : Returns a Value * if the text was a value, otherwise NULL.
+ * @val : Returns a GnmValue * if the text was a value, otherwise NULL.
  * @expr: Returns an GnmExpr * if the text was an expression, otherwise NULL.
  * @cur_fmt : Optional, current number format.
  * @date_conv : Optional, date parse conventions
  *
- * If there is a parse failure for an expression an error Value with the syntax
+ * If there is a parse failure for an expression an error GnmValue with the syntax
  * error is returned.
  */
 void
 parse_text_value_or_expr (ParsePos const *pos, char const *text,
-			  Value **val, GnmExpr const **expr,
+			  GnmValue **val, GnmExpr const **expr,
 			  StyleFormat *cur_fmt,
 			  GnmDateConventions const *date_conv)
 {
@@ -735,7 +735,7 @@ sheetref_parse (char const *start, Sheet **sheet, Workbook const *wb,
 		gboolean allow_3d)
 {
 	GString *sheet_name;
-	const char *end;
+	char const *end;
 
 	*sheet = NULL;
 	if (*start == '\'' || *start == '"') {
@@ -774,7 +774,7 @@ sheetref_parse (char const *start, Sheet **sheet, Workbook const *wb,
  * If the result != @start then @res is valid.
  **/
 char const *
-rangeref_parse (RangeRef *res, char const *start, ParsePos const *pp)
+rangeref_parse (GnmRangeRef *res, char const *start, ParsePos const *pp)
 {
 	char const *ptr = start, *start_sheet, *tmp1, *tmp2;
 	Workbook *wb;
@@ -820,7 +820,7 @@ rangeref_parse (RangeRef *res, char const *start, ParsePos const *pp)
 	}
 
 	tmp2 = row_parse (tmp1, &res->a.row, &res->a.row_relative);
-	if (!tmp2) { /* check for col only ref B:C */
+	if (!tmp2) { /* check for col only ref B:C or R1C1 style */
 		if (*tmp1++ != ':') /* col only requires : even for singleton */
 			return start;
 		tmp2 = col_parse (tmp1, &res->b.col, &res->b.col_relative);
@@ -865,7 +865,7 @@ rangeref_parse (RangeRef *res, char const *start, ParsePos const *pp)
 
 
 char const *
-gnm_1_0_rangeref_parse (RangeRef *res, char const *start, ParsePos const *pp)
+gnm_1_0_rangeref_parse (GnmRangeRef *res, char const *start, ParsePos const *pp)
 {
 	char const *ptr = start, *tmp1, *tmp2;
 	Workbook *wb;
@@ -920,11 +920,11 @@ gnm_1_0_rangeref_parse (RangeRef *res, char const *start, ParsePos const *pp)
 
 static void
 def_expr_name_handler (GString *target,
-		       const ParsePos *pp,
-		       const GnmExprName *name,
-		       const GnmExprConventions *conv)
+		       ParsePos const *pp,
+		       GnmExprName const *name,
+		       GnmExprConventions const *conv)
 {
-	const GnmNamedExpr *thename = name->name;
+	GnmNamedExpr const *thename = name->name;
 
 	if (!thename->active) {
 		g_string_append (target,
@@ -982,7 +982,7 @@ static void
 test_col_stuff (void)
 {
 	int col;
-	const char *end, *str;
+	char const *end, *str;
 	unsigned char col_relative;
 
 	g_assert (strcmp ("A", col_name (0)) == 0);
@@ -1016,7 +1016,7 @@ static void
 test_row_stuff (void)
 {
 	int row;
-	const char *end, *str;
+	char const *end, *str;
 	unsigned char row_relative;
 
 	g_assert (strcmp ("1", row_name (0)) == 0);
@@ -1058,8 +1058,8 @@ test_row_stuff (void)
 static void
 test_cellpos_stuff (void)
 {
-	CellPos cp;
-	const char *end, *str;
+	GnmCellPos cp;
+	char const *end, *str;
 
 	end = cellpos_parse ((str = "A1"), &cp, TRUE);
 	g_assert (end == str + strlen (str) && cp.col == 0 && cp.row == 0);
