@@ -4,25 +4,25 @@
 #include "gnumeric.h"
 
 struct _EvalPos {
-	CellPos    eval;
-	Sheet     *sheet;
-	Dependent *dep; /* optionally NULL */
+	GnmCellPos   eval;
+	Sheet      *sheet;
+	Dependent  *dep; /* optionally NULL */
 };
 
 struct _ParsePos {
-	CellPos   eval;
-	Sheet    *sheet;
-	Workbook *wb;
+	GnmCellPos  eval;
+	Sheet	   *sheet;
+	Workbook   *wb;
 };
 
 /**
- * Used for getting a valid Sheet *from a CellRef
- * Syntax is CellRef, valid Sheet *
+ * Used for getting a valid Sheet *from a GnmCellRef
+ * Syntax is GnmCellRef, valid Sheet *
  */
 #define eval_sheet(a,b)     (((a) != NULL) ? (a) : (b))
 
 /* Initialization routines for Evaluation Positions */
-EvalPos  *eval_pos_init		(EvalPos *ep, Sheet *s, CellPos const *pos);
+EvalPos  *eval_pos_init		(EvalPos *ep, Sheet *s, GnmCellPos const *pos);
 EvalPos  *eval_pos_init_dep	(EvalPos *ep, Dependent const *dep);
 EvalPos  *eval_pos_init_cell	(EvalPos *ep, Cell const *cell);
 EvalPos  *eval_pos_init_sheet	(EvalPos *ep, Sheet *sheet);
@@ -38,34 +38,34 @@ ParsePos *parse_pos_init_sheet	 (ParsePos *pp, Sheet *sheet);
 
 /*****************************************************************************/
 
-struct _CellRef {
+struct _GnmCellRef {
 	Sheet *sheet;
 	int   col, row;
 
 	unsigned char col_relative;
 	unsigned char row_relative;
 };
-struct _RangeRef {
-	CellRef a, b;
+struct _GnmRangeRef {
+	GnmCellRef a, b;
 };
 
-CellRef   *cellref_set          (CellRef *ref, Sheet *sheet, int col, int row,
+GnmCellRef *cellref_set         (GnmCellRef *ref, Sheet *sheet, int col, int row,
 				 gboolean rel);
-gboolean  cellref_equal		(CellRef const *a, CellRef const *b);
-void      cellref_make_abs	(CellRef *dest,
-				 CellRef const *src,
+gboolean  cellref_equal		(GnmCellRef const *a, GnmCellRef const *b);
+void      cellref_make_abs	(GnmCellRef *dest,
+				 GnmCellRef const *src,
 				 EvalPos const *ep);
-int       cellref_get_abs_col	(CellRef const *ref,
+int       cellref_get_abs_col	(GnmCellRef const *ref,
 				 EvalPos const *pos);
-int       cellref_get_abs_row	(CellRef const *cell_ref,
+int       cellref_get_abs_row	(GnmCellRef const *cell_ref,
 				 EvalPos const *src_fp);
-void      cellref_get_abs_pos	(CellRef const *cell_ref,
-				 CellPos const *pos,
-				 CellPos *res);
-guint     cellref_hash          (CellRef const *cr);
+void      cellref_get_abs_pos	(GnmCellRef const *cell_ref,
+				 GnmCellPos const *pos,
+				 GnmCellPos *res);
+guint     cellref_hash          (GnmCellRef const *cr);
 
-RangeRef *value_to_rangeref    (Value *v, gboolean release);
-void      rangeref_normalize   (RangeRef const *ref, EvalPos const *ep,
-				Sheet **start_sheet, Sheet **end_sheet, Range *dest);
+GnmRangeRef *value_to_rangeref    (GnmValue *v, gboolean release);
+void         rangeref_normalize   (GnmRangeRef const *ref, EvalPos const *ep,
+				Sheet **start_sheet, Sheet **end_sheet, GnmRange *dest);
 
 #endif /* GNUMERIC_POSITION_H */
