@@ -16,7 +16,8 @@ char const  *cell_comment_text_get   (CellComment const *cc);
 void         cell_comment_text_set   (CellComment       *cc, char const *);
 
 /* convenience routine */
-CellComment *cell_set_comment (Sheet *sheet, CellPos const *pos,
+void	     cell_comment_set_cell   (CellComment *cc, GnmCellPos const *pos);
+CellComment *cell_set_comment (Sheet *sheet, GnmCellPos const *pos,
 			       char const *author, char const *text);
 
 #endif /* GNUMERIC_SHEET_OBJECT_CELL_COMMENT_H */
