@@ -22,6 +22,8 @@
 #include "dialogs/help.h"
 
 #include <gdk/gdkkeysyms.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkspinbutton.h>
 #include <gsf/gsf-impl-utils.h>
 #include <widgets/widget-color-combo.h>
 #include <libfoocanvas/foo-canvas-line.h>
@@ -492,10 +494,10 @@ sheet_object_graphic_user_config (SheetObject *so, SheetControl *sc)
 	color_combo_set_color (COLOR_COMBO (w),
 		sog->fill_color ? &sog->fill_color->color : NULL);
 	color_combo_set_instant_apply (COLOR_COMBO (w), FALSE);
-	gtk_combo_box_set_tearable (GTK_COMBO_BOX (w), FALSE);
+	gnm_combo_box_set_tearable (GNM_COMBO_BOX (w), FALSE);
 	state->fill_color = style_color_ref (sog->fill_color);
 	gtk_table_attach_defaults (GTK_TABLE (table), w, 1, 2, 0, 1);
-	gtk_combo_box_set_arrow_relief (GTK_COMBO_BOX (w), GTK_RELIEF_NORMAL);
+	gnm_combo_box_set_arrow_relief (GNM_COMBO_BOX (w), GTK_RELIEF_NORMAL);
 	color_combo_box_set_preview_relief (COLOR_COMBO (w), GTK_RELIEF_NORMAL);
 	gtk_widget_show (GTK_WIDGET (w));
 	g_signal_connect (G_OBJECT (w),
@@ -942,10 +944,10 @@ sheet_object_filled_user_config (SheetObject *so, SheetControl *sc)
 	color_combo_set_color (COLOR_COMBO (w),
 		sof->outline_color ? &sof->outline_color->color : NULL);
 	color_combo_set_instant_apply (COLOR_COMBO (w), FALSE);
-	gtk_combo_box_set_tearable (GTK_COMBO_BOX (w), FALSE);
+	gnm_combo_box_set_tearable (GNM_COMBO_BOX (w), FALSE);
 	state->outline_color = style_color_ref (sof->outline_color);
 	gtk_table_attach_defaults (GTK_TABLE (table), w, 1, 2, 0, 1);
-	gtk_combo_box_set_arrow_relief (GTK_COMBO_BOX (w), GTK_RELIEF_NORMAL);
+	gnm_combo_box_set_arrow_relief (GNM_COMBO_BOX (w), GTK_RELIEF_NORMAL);
 	color_combo_box_set_preview_relief (COLOR_COMBO (w), GTK_RELIEF_NORMAL);
 	gtk_widget_show (GTK_WIDGET (w));
 	g_signal_connect (G_OBJECT (w),
@@ -961,10 +963,10 @@ sheet_object_filled_user_config (SheetObject *so, SheetControl *sc)
 	color_combo_set_color (COLOR_COMBO (w),
 		sog->fill_color ? &sog->fill_color->color : NULL);
 	color_combo_set_instant_apply (COLOR_COMBO (w), FALSE);
-	gtk_combo_box_set_tearable (GTK_COMBO_BOX (w), FALSE);
+	gnm_combo_box_set_tearable (GNM_COMBO_BOX (w), FALSE);
 	state->fill_color = style_color_ref (sog->fill_color);
 	gtk_table_attach_defaults (GTK_TABLE (table), w, 1, 2, 1, 2);
-	gtk_combo_box_set_arrow_relief (GTK_COMBO_BOX (w), GTK_RELIEF_NORMAL);
+	gnm_combo_box_set_arrow_relief (GNM_COMBO_BOX (w), GTK_RELIEF_NORMAL);
 	color_combo_box_set_preview_relief (COLOR_COMBO (w), GTK_RELIEF_NORMAL);
 	gtk_widget_show (GTK_WIDGET (w));
 	g_signal_connect (G_OBJECT (w),
