@@ -121,7 +121,7 @@ stf_apply_formats (StfParseOptions_t *parseoptions,
 		   Sheet *sheet, int col, int start_row, int end_row)
 {
 	unsigned int ui;
-	Range range;
+	GnmRange range;
 
 	/* If we didn't use the stf dialog, then formats will be NULL */
 	if (parseoptions->formats == NULL)
@@ -220,25 +220,27 @@ stf_read_workbook (GnmFileOpener const *fo,  gchar const *enc,
 		stf_dialog_result_free (dialogresult);
 }
 
-static Value *
+static GnmValue *
 cb_get_content (Sheet *sheet, int col, int row,
 		Cell *cell, GsfOutput *buf)
 {
-	char *tmp;
-	if (cell_has_expr (cell)) {
-		ParsePos pp;
-		tmp = gnm_expr_as_string (cell->base.expression,
-			parse_pos_init_cell (&pp, cell),
-			gnm_expr_conventions_default);
-	} else if (VALUE_FMT (cell->value) != NULL)
-		tmp = format_value (NULL, cell->value, NULL, -1,
-				    workbook_date_conv (sheet->workbook));
-	else
-		tmp = value_get_as_string (cell->value);
+	if (cell != NULL) {
+		char *tmp;
+		if (cell_has_expr (cell)) {
+			ParsePos pp;
+			tmp = gnm_expr_as_string (cell->base.expression,
+				parse_pos_init_cell (&pp, cell),
+				gnm_expr_conventions_default);
+		} else if (VALUE_FMT (cell->value) != NULL)
+			tmp = format_value (NULL, cell->value, NULL, -1,
+				workbook_date_conv (sheet->workbook));
+		else
+			tmp = value_get_as_string (cell->value);
 
-	gsf_output_write (buf, strlen (tmp), tmp);
+		gsf_output_write (buf, strlen (tmp), tmp);
+		g_free (tmp);
+	}
 	gsf_output_write (buf, 1, "\n");
-	g_free (tmp);
 
 	return NULL;
 }
@@ -255,8 +257,8 @@ stf_text_to_columns (WorkbookControl *wbc, CommandContext *cc)
 	DialogStfResult_t *dialogresult = NULL;
 	SheetView	*sv;
 	Sheet		*src_sheet, *target_sheet;
-	Range const	*src;
-	Range		 target;
+	GnmRange const	*src;
+	GnmRange		 target;
 	GsfOutputMemory	*buf;
 	guint8 const	*data;
 	size_t data_len;
@@ -284,7 +286,7 @@ stf_text_to_columns (WorkbookControl *wbc, CommandContext *cc)
 
 	buf = gsf_output_memory_new ();
 	sheet_foreach_cell_in_range (src_sheet,
-		CELL_ITER_IGNORE_BLANK | CELL_ITER_IGNORE_HIDDEN,
+		CELL_ITER_ALL,
 		src->start.col, src->start.row,
 		src->end.col, src->end.row,
 		(CellIterFunc) &cb_get_content, buf);
@@ -303,15 +305,16 @@ stf_text_to_columns (WorkbookControl *wbc, CommandContext *cc)
 					   data, data_len);
 	}
 	if (dialogresult != NULL) {
-		CellRegion *cr = NULL;
-
-		cr = stf_parse_region (dialogresult->parseoptions, dialogresult->text, NULL);
+		CellRegion *cr = stf_parse_region (dialogresult->parseoptions,
+						   dialogresult->text, NULL);
 		if (cr != NULL) {
 			stf_dialog_result_attach_formats_to_cr (dialogresult, cr);
 			target.end.col = target.start.col + cr->cols - 1;
+			target.end.row = target.start.row + cr->rows - 1;
 		}
-		if (cr == NULL || cmd_text_to_columns (wbc, src, src_sheet, 
-						      &target, target_sheet, cr))
+		if (cr == NULL ||
+		    cmd_text_to_columns (wbc, src, src_sheet, 
+					 &target, target_sheet, cr))
 			gnumeric_error_read (COMMAND_CONTEXT (cc),
 					     _("Error while trying to "
 					       "parse data into sheet"));
@@ -429,17 +432,16 @@ stf_write_workbook (GnmFileSaver const *fs, IOContext *context,
 static gboolean
 csv_tsv_probe (GnmFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
 {
-	if (pl == FILE_PROBE_FILE_NAME) {
-		char const *name = gsf_input_name (input);
-		if (name == NULL)
-			return FALSE;
-		name = gsf_extension_pointer (name);
-		return (name != NULL &&
-		        (g_ascii_strcasecmp (name, "csv") == 0 ||
-			 g_ascii_strcasecmp (name, "tsv") == 0));
-	} else if (pl == FILE_PROBE_CONTENT)
-		return TRUE;
-	return FALSE;
+	/* always probe by name.  We can not really tell what encoding is in use
+	 * so its hard to spot invalid data, and we do not want stuff to just
+	 * get sucked in by default */
+	char const *name = gsf_input_name (input);
+	if (name == NULL)
+		return FALSE;
+	name = gsf_extension_pointer (name);
+	return (name != NULL &&
+		(g_ascii_strcasecmp (name, "csv") == 0 ||
+		 g_ascii_strcasecmp (name, "tsv") == 0));
 }
 
 void
