@@ -46,6 +46,7 @@ struct _StyleFont {
 			double digit, decimal, sign, E, e, hash;
 		} pixels, pts;
 	} approx_width;
+	double	 height;
 	struct {
 		PangoContext		*context;
 		PangoFontMetrics	*metrics;
@@ -82,6 +83,7 @@ GnomeFont *gnm_font_find_closest_from_weight_slant (const guchar *family,
 						    GnomeFontWeight weight, 
 						    gboolean italic, 
 						    gdouble size);
+PangoContext *gnm_pango_context_get (void);
 
 #include "mstyle.h"
 
