@@ -31,7 +31,6 @@
 
 #include "mathfunc.h"
 #include "rangefunc.h"
-#include "parse-util.h"
 #include "tools.h"
 #include "value.h"
 #include "cell.h"
@@ -57,8 +56,8 @@
 
 typedef struct {
 	gint n;
-	Value **values;
-	gnum_float *cumul_p;
+	GnmValue **values;
+	gnm_float *cumul_p;
 } discrete_random_tool_local_t;
 
 static void
@@ -77,30 +76,30 @@ tool_random_engine_run_discrete_clear_continuity (discrete_random_tool_local_t *
 }
 
 static gboolean
-tool_random_engine_run_discrete_last_check (data_analysis_output_t *dao, 
+tool_random_engine_run_discrete_last_check (G_GNUC_UNUSED data_analysis_output_t *dao,
 					    tools_data_random_t *info,
 					    discrete_random_tool_t *param,
 					    discrete_random_tool_local_t **continuity)
 {
 	discrete_random_tool_local_t *data;
-	Value *range = param->range;
-	gnum_float cumprob = 0;
+	GnmValue *range = param->range;
+	gnm_float cumprob = 0;
 	int j = 0;
 	int i;
 
 	data = *continuity = g_new0 (discrete_random_tool_local_t, 1);
 	data->n = range->v_range.cell.b.row - range->v_range.cell.a.row + 1;
-	data->cumul_p = g_new (gnum_float, data->n);
-	data->values = g_new0 (Value *, data->n);
+	data->cumul_p = g_new (gnm_float, data->n);
+	data->values = g_new0 (GnmValue *, data->n);
 
 	for (i = range->v_range.cell.a.row;
 	     i <= range->v_range.cell.b.row;
 	     i++, j++) {
-		Value *v;
-		gnum_float thisprob;
+		GnmValue *v;
+		gnm_float thisprob;
 		Cell *cell = sheet_cell_get (range->v_range.cell.a.sheet,
 					     range->v_range.cell.a.col + 1, i);
-		
+
 		if (cell == NULL ||
 		    (v = cell->value) == NULL ||
 		    !VALUE_IS_NUMBER (v)) {
@@ -119,23 +118,23 @@ tool_random_engine_run_discrete_last_check (data_analysis_output_t *dao,
 					   "non-negative!"));
 			goto random_tool_discrete_out;
 		}
-		
+
 		cumprob += thisprob;
 		data->cumul_p[j] = cumprob;
-		
+
 		cell = sheet_cell_get (range->v_range.cell.a.sheet,
 				       range->v_range.cell.a.col, i);
-		
+
 		if (cell == NULL || cell->value == NULL) {
 			gnumeric_error_calc (COMMAND_CONTEXT (info->wbc),
 					 _("None of the values in the value "
 					   "range may be empty!"));
 			goto random_tool_discrete_out;
 		}
-		
+
 		data->values[j] = value_duplicate (cell->value);
 	}
-	
+
 	if (cumprob != 0) {
 		/* Rescale... */
 		for (i = 0; i < data->n; i++) {
@@ -147,14 +146,14 @@ tool_random_engine_run_discrete_last_check (data_analysis_output_t *dao,
 			 _("The probabilities may not all be 0!"));
 
  random_tool_discrete_out:
-	tool_random_engine_run_discrete_clear_continuity (continuity);	
+	tool_random_engine_run_discrete_clear_continuity (continuity);
 	return TRUE;
 }
 
 static gboolean
-tool_random_engine_run_discrete (data_analysis_output_t *dao, 
+tool_random_engine_run_discrete (data_analysis_output_t *dao,
 				 tools_data_random_t *info,
-				 discrete_random_tool_t *param,
+				 G_GNUC_UNUSED discrete_random_tool_t *param,
 				 discrete_random_tool_local_t **continuity)
 {
 	gint i;
@@ -164,11 +163,11 @@ tool_random_engine_run_discrete (data_analysis_output_t *dao,
 		int k;
 		for (k = 0; k < info->count; k++) {
 			int j;
-			gnum_float x = random_01 ();
-			
+			gnm_float x = random_01 ();
+
 			for (j = 0; data->cumul_p[j] < x; j++)
 				;
-			
+
 			dao_set_cell_value (dao, i, k,
 					    value_duplicate (data->values[j]));
 		}
@@ -183,15 +182,15 @@ tool_random_engine_run_uniform (data_analysis_output_t *dao,
 				uniform_random_tool_t *param)
 {
 	int i, n;
-	gnum_float range = param->upper_limit - param->lower_limit;
+	gnm_float range = param->upper_limit - param->lower_limit;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = range * random_01 () + param->lower_limit;
 			dao_set_cell_float (dao, i, n, v);
 		}
 	}
-	
+
 	return FALSE;
 }
 
@@ -201,17 +200,17 @@ tool_random_engine_run_uniform_int (data_analysis_output_t *dao,
 				    uniform_random_tool_t *param)
 {
 	int        i, n;
-	gnum_float lower = floorgnum (param->lower_limit);
-	gnum_float range = floorgnum (param->upper_limit) - lower;
+	gnm_float lower = floorgnum (param->lower_limit);
+	gnm_float range = floorgnum (param->upper_limit) - lower;
 
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = floorgnum (0.5 + range * random_01 ()) + lower;
 			dao_set_cell_float (dao, i, n, v);
 		}
 	}
-	
+
 	return FALSE;
 }
 
@@ -223,7 +222,7 @@ tool_random_engine_run_normal (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = param->stdev * random_normal () + param->mean;
 			dao_set_cell_float (dao, i, n, v);
 		}
@@ -239,7 +238,7 @@ tool_random_engine_run_bernoulli (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float tmp = random_bernoulli (param->p);
+			gnm_float tmp = random_bernoulli (param->p);
 			dao_set_cell_int (dao, i, n, (int)tmp);
 		}
 	}
@@ -254,7 +253,7 @@ tool_random_engine_run_beta (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float tmp = random_beta (param->a, param->b);
+			gnm_float tmp = random_beta (param->a, param->b);
 			dao_set_cell_float (dao, i, n, tmp);
 		}
 	}
@@ -269,12 +268,12 @@ tool_random_engine_run_binomial (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_binomial (param->p,
 					     param->trials);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -286,7 +285,7 @@ tool_random_engine_run_negbinom (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_negbinom (param->p,
 					     param->f);
 			dao_set_cell_float (dao, i, n, v);
@@ -303,7 +302,7 @@ tool_random_engine_run_poisson (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_poisson (param->lambda);
 			dao_set_cell_float (dao, i, n, v);
 		}
@@ -319,11 +318,11 @@ tool_random_engine_run_exponential (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_exponential (param->b);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -335,11 +334,11 @@ tool_random_engine_run_exppow (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_exppow (param->a, param->b);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -351,11 +350,11 @@ tool_random_engine_run_cauchy (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_cauchy (param->a);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -367,11 +366,11 @@ tool_random_engine_run_chisq (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_chisq (param->nu);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -383,11 +382,11 @@ tool_random_engine_run_pareto (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_pareto (param->a, param->b);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -399,11 +398,11 @@ tool_random_engine_run_rayleigh (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_rayleigh (param->sigma);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -415,11 +414,11 @@ tool_random_engine_run_rayleigh_tail (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_rayleigh_tail (param->a, param->sigma);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -431,11 +430,11 @@ tool_random_engine_run_levy (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_levy (param->c, param->alpha);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -447,11 +446,11 @@ tool_random_engine_run_fdist (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_fdist (param->nu1, param->nu2);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -463,11 +462,11 @@ tool_random_engine_run_lognormal (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_lognormal (param->zeta, param->sigma);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -479,11 +478,11 @@ tool_random_engine_run_logarithmic (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_logarithmic (param->p);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -495,11 +494,11 @@ tool_random_engine_run_logistic (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_logistic (param->a);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -511,11 +510,11 @@ tool_random_engine_run_tdist (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_tdist (param->nu);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -527,11 +526,11 @@ tool_random_engine_run_gamma (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_gamma (param->a, param->b);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -543,11 +542,11 @@ tool_random_engine_run_geometric (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_geometric (param->p);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -559,11 +558,11 @@ tool_random_engine_run_weibull (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_weibull (param->a, param->b);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -575,11 +574,11 @@ tool_random_engine_run_laplace (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_laplace (param->a);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -591,11 +590,11 @@ tool_random_engine_run_gaussian_tail (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_gaussian_tail (param->a, param->sigma);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -606,11 +605,11 @@ tool_random_engine_run_landau (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_landau ();
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -622,11 +621,11 @@ tool_random_engine_run_gumbel1 (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_gumbel1 (param->a, param->b);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -638,11 +637,11 @@ tool_random_engine_run_gumbel2 (data_analysis_output_t *dao,
 	int i, n;
 	for (i = 0; i < info->n_vars; i++) {
 		for (n = 0; n < info->count; n++) {
-			gnum_float v;
+			gnm_float v;
 			v = random_gumbel2 (param->a, param->b);
 			dao_set_cell_float (dao, i, n, v);
 		}
-	}	
+	}
 	return FALSE;
 }
 
@@ -766,7 +765,7 @@ tool_random_engine (data_analysis_output_t *dao, gpointer specs,
 		case BinomialDistribution:
 			return tool_random_engine_run_binomial
 			        (dao, specs, &info->param.binomial);
-		case NegativeBinomialDistribution:	
+		case NegativeBinomialDistribution:
 			return tool_random_engine_run_negbinom
 			        (dao, specs, &info->param.negbinom);
 		}
