@@ -30,7 +30,6 @@
 
 #include <gnumeric-config.h>
 
-#include <gtk/gtk.h>
 #include <libfoocanvas/foo-canvas.h>
 #include <libfoocanvas/foo-canvas-pixbuf.h>
 #include <libfoocanvas/foo-canvas-rect-ellipse.h>
@@ -39,8 +38,7 @@
 #include <gui-util.h>
 #include <style-color.h>
 #include "widget-color-combo.h"
-#include <gnm-marshalers.h>
-#include <gsf/gsf-impl-utils.h>
+#include <gtk/gtkimage.h>
 
 enum {
 	CHANGED,
@@ -49,7 +47,7 @@ enum {
 
 static guint color_combo_signals [LAST_SIGNAL] = { 0, };
 
-#define PARENT_TYPE GTK_COMBO_BOX_TYPE
+#define PARENT_TYPE GNM_COMBO_BOX_TYPE
 static GObjectClass *color_combo_parent_class;
 
 #define make_color(CC,COL) (((COL) != NULL) ? (COL) : ((CC) ? ((CC)->default_color) : NULL))
@@ -149,7 +147,7 @@ emit_color_changed (ColorCombo *cc, GdkColor *color,
   	g_signal_emit (cc,
 		       color_combo_signals [CHANGED], 0,
 		       color, is_custom, by_user, is_default);
-	gtk_combo_box_popup_hide (GTK_COMBO_BOX (cc));
+	gnm_combo_box_popup_hide (GNM_COMBO_BOX (cc));
 }
 
 static void
@@ -177,13 +175,13 @@ preview_clicked (GtkWidget *button, ColorCombo *cc)
 	if (cc->instant_apply)
 		apply_current_color (cc);
 	else
-		gtk_combo_box_popup_display (GTK_COMBO_BOX (cc));
+		gnm_combo_box_popup_display (GNM_COMBO_BOX (cc));
 }
 
 static void
 cb_cust_color_clicked (GtkWidget *widget, ColorCombo *cc)
 {
-	gtk_combo_box_popup_hide (GTK_COMBO_BOX (cc));
+	gnm_combo_box_popup_hide (GNM_COMBO_BOX (cc));
 }
 
 /*
@@ -274,7 +272,7 @@ color_combo_construct (ColorCombo *cc, GdkPixbuf *icon,
 
 	gtk_widget_show_all (cc->preview_button);
 
-	gtk_combo_box_construct (GTK_COMBO_BOX (cc),
+	gnm_combo_box_construct (GNM_COMBO_BOX (cc),
 				 cc->preview_button,
 				 GTK_WIDGET (cc->palette));
 
