@@ -18,23 +18,30 @@
  **/
 
 #include <gnumeric-config.h>
+#include "widget-format-selector.h"
+
 #include <gnumeric-i18n.h>
 
-#include <string.h>
 #include <format.h>
 #include <mstyle.h>
 #include <style-color.h>
 #include <sheet.h>
 #include <value.h>
-#include <workbook.h>
-#include <locale.h>
 #include <gnm-marshalers.h>
 
 #include <widgets/gnumeric-combo-text.h>
 
+#include <gtk/gtksizegroup.h>
+#include <gtk/gtktreeview.h>
+#include <gtk/gtktreeselection.h>
+#include <gtk/gtkspinbutton.h>
+#include <gtk/gtktogglebutton.h>
+#include <gtk/gtkcellrenderertext.h>
+#include <gtk/gtkliststore.h>
 #include <gsf/gsf-impl-utils.h>
 
-#include "widget-format-selector.h"
+#include <string.h>
+#include <locale.h>
 
 /* The maximum number of chars in the formatting sample */
 #define FORMAT_PREVIEW_MAX 25
@@ -106,13 +113,13 @@ typedef enum {
 } FormatWidget;
 
 struct  _NumberFormatSelector {
-	GtkHBox 	box;
-	GladeXML 	*gui;
+	GtkHBox   box;
+	GladeXML *gui;
 
-	Value		*value;
-	char *  	locale;
+	GnmValue *value;
+	char	 *locale;
 
-	gboolean	enable_edit;
+	gboolean  enable_edit;
 
 	GnmDateConventions const *date_conv;
 
@@ -907,7 +914,7 @@ nfs_init (NumberFormatSelector *nfs)
 	gtk_widget_set_size_request (nfs->format.widget[F_LIST], -1, 100);
 	gtk_widget_set_size_request (nfs->format.widget[F_NEGATIVE], -1, 100);
 
-	/* use size group for better widget alignement */
+	/* use size group for better widget alignment */
 	nfs->format.size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	gtk_size_group_add_widget (nfs->format.size_group,
 				   nfs->format.widget[F_SYMBOL_LABEL]);
@@ -1101,7 +1108,7 @@ number_format_selector_set_style_format (NumberFormatSelector *nfs,
 
 void
 number_format_selector_set_value (NumberFormatSelector *nfs,
-				  Value const *value)
+				  GnmValue const *value)
 {
   	g_return_if_fail (IS_NUMBER_FORMAT_SELECTOR (nfs));
 	g_return_if_fail (value != NULL);
